@@ -95,8 +95,8 @@ fi
 #
 # Use kustomize to patch the deployment resource
 #
-pushd config/manager > /dev/null
-kustomize edit add patch --path patch-image-pull-policy-always.yaml --kind Deployment
+pushd pkg/resources/config/manager > /dev/null
+kustomize edit add patch --path patch-image-pull-policy-always.yaml --kind Deployment --name camel-k-operator
 popd
 
 #
@@ -110,7 +110,7 @@ export PUSH_BUNDLE_LOCAL_IMAGE=${REGISTRY_PUSH_HOST}/${IMAGE_NAMESPACE}/${BUNDLE
 export CUSTOM_IMAGE=${IMAGE_NAME}
 export CUSTOM_VERSION=${IMAGE_VERSION}
 
-export PREV_XY_CHANNEL="stable-$(make get-last-released-version | grep -Po '\d+\.\d+')"
+export PREV_XY_CHANNEL=stable-v$(make get-last-released-version | grep -Po "\d+" | head -n 1)
 echo "PREV_XY_CHANNEL=${PREV_XY_CHANNEL}" >> $GITHUB_ENV
 export NEW_XY_CHANNEL=stable-dev-$(make get-version | grep -Po "\d+\.\d+")
 echo "NEW_XY_CHANNEL=${NEW_XY_CHANNEL}" >> $GITHUB_ENV
