@@ -21,6 +21,7 @@ import (
 	"encoding/json"
 	"fmt"
 	"os"
+	"path/filepath"
 	"reflect"
 	"strings"
 
@@ -41,7 +42,7 @@ func main() {
 	schema := os.Args[2]
 	path := os.Args[3]
 	isArray := os.Args[4] == "true"
-	destination := os.Args[5]
+	destination := filepath.Clean(os.Args[5])
 
 	if err := generate(crd, schema, path, isArray, destination); err != nil {
 		panic(err)
