@@ -37,6 +37,7 @@ import (
 // +kubebuilder:printcolumn:name="Type",type=string,JSONPath=`.metadata.labels.camel\.apache\.org\/kit\.type`,description="The integration kit type"
 // +kubebuilder:printcolumn:name="Layout",type=string,JSONPath=`.metadata.labels.camel\.apache\.org\/kit\.layout`,description="The integration kit layout"
 // +kubebuilder:printcolumn:name="Image",type=string,JSONPath=`.status.image`,description="The integration kit image"
+// +kubebuilder:printcolumn:name="Root",type=string,JSONPath=`.status.rootImage`,description="The integration kit root image"
 
 // IntegrationKit defines a container image and additional configuration needed to run an `Integration`.
 // An `IntegrationKit` is a generic image generally built from the requirements of an `Integration`, but agnostic to it,
@@ -52,7 +53,7 @@ type IntegrationKit struct {
 	Status IntegrationKitStatus `json:"status,omitempty"`
 }
 
-// IntegrationKitSpec defines a container image and additional configurations required to kick off an `Integration` with certain features
+// IntegrationKitSpec defines a container image and additional configurations required to kick off an `Integration` with certain features.
 type IntegrationKitSpec struct {
 	// the container image as identified in the container registry
 	Image string `json:"image,omitempty"`
@@ -73,9 +74,11 @@ type IntegrationKitSpec struct {
 	Repositories []string `json:"repositories,omitempty"`
 	// the sources to add at build time
 	Sources []SourceSpec `json:"sources,omitempty"`
+	// features offered by the IntegrationKit
+	Capabilities []string `json:"capabilities,omitempty"`
 }
 
-// IntegrationKitTraits defines traits assigned to an `IntegrationKit`
+// IntegrationKitTraits defines traits assigned to an `IntegrationKit`.
 type IntegrationKitTraits struct {
 	// The builder trait is internally used to determine the best strategy to build and configure IntegrationKits.
 	Builder *trait.BuilderTrait `property:"builder" json:"builder,omitempty"`
@@ -83,21 +86,24 @@ type IntegrationKitTraits struct {
 	Camel *trait.CamelTrait `property:"camel" json:"camel,omitempty"`
 	// The Quarkus trait configures the Quarkus runtime.
 	// It's enabled by default.
-	// NOTE: Compiling to a native executable, i.e. when using `package-type=native`, is only supported for kamelets, as well as YAML and XML integrations. It also requires at least 4GiB of memory, so the Pod running the native build, that is either the operator Pod, or the build Pod (depending on the build strategy configured for the platform), must have enough memory available.
+	// NOTE: Compiling to a native executable, requires at least 4GiB of memory, so the Pod running the native build must have enough memory available.
 	Quarkus *trait.QuarkusTrait `property:"quarkus" json:"quarkus,omitempty"`
 	// The Registry trait sets up Maven to use the Image registry as a Maven repository.
+	// Deprecated: use jvm trait or read documentation.
 	Registry *trait.RegistryTrait `property:"registry" json:"registry,omitempty"`
 	// The collection of addon trait configurations
 	Addons map[string]AddonTrait `json:"addons,omitempty"`
 }
 
-// IntegrationKitStatus defines the observed state of IntegrationKit
+// IntegrationKitStatus defines the observed state of IntegrationKit.
 type IntegrationKitStatus struct {
 	// ObservedGeneration is the most recent generation observed for this IntegrationKit.
 	ObservedGeneration int64 `json:"observedGeneration,omitempty"`
 	// phase of the kit
 	Phase IntegrationKitPhase `json:"phase,omitempty"`
-	// base image used by the kit
+	// root image used by the kit (the first image from which the incremental image has started, typically a JDK/JRE base image)
+	RootImage string `json:"rootImage,omitempty"`
+	// base image used by the kit (could be another IntegrationKit)
 	BaseImage string `json:"baseImage,omitempty"`
 	// actual image name of the kit
 	Image string `json:"image,omitempty"`
@@ -121,67 +127,71 @@ type IntegrationKitStatus struct {
 
 // +kubebuilder:object:root=true
 
-// IntegrationKitList contains a list of IntegrationKit
+// IntegrationKitList contains a list of IntegrationKit.
 type IntegrationKitList struct {
 	metav1.TypeMeta `json:",inline"`
 	metav1.ListMeta `json:"metadata,omitempty"`
 	Items           []IntegrationKit `json:"items"`
 }
 
-// IntegrationKitPhase --
+// IntegrationKitPhase --.
 type IntegrationKitPhase string
 
-// IntegrationKitConditionType --
+// IntegrationKitConditionType --.
 type IntegrationKitConditionType string
 
 const (
-	// IntegrationKitKind --
+	// IntegrationKitKind --.
 	IntegrationKitKind string = "IntegrationKit"
 
-	// IntegrationKitTypeLabel labels the kit type
+	// IntegrationKitTypeLabel labels the kit type.
 	IntegrationKitTypeLabel = "camel.apache.org/kit.type"
 
-	// IntegrationKitTypePlatform identifies a kit created by the platform
+	// IntegrationKitTypePlatform identifies a kit created by the platform.
 	IntegrationKitTypePlatform = "platform"
-	// IntegrationKitTypeUser identifies a kit created by the user
+	// IntegrationKitTypeUser identifies a kit created by the user.
 	IntegrationKitTypeUser = "user"
-	// IntegrationKitTypeExternal identifies a kit created by any third party
+	// IntegrationKitTypeExternal identifies a kit created by any third party.
 	IntegrationKitTypeExternal = "external"
 
-	// IntegrationKitLayoutLabel labels the kit layout
+	// IntegrationKitLayoutLabel labels the kit layout.
 	IntegrationKitLayoutLabel = "camel.apache.org/kit.layout"
 
-	// IntegrationKitLayoutFastJar labels a kit using the Quarkus fast-jar packaging
+	// IntegrationKitLayoutFastJar labels a kit using the Quarkus fast-jar packaging.
 	IntegrationKitLayoutFastJar = "fast-jar"
-	// IntegrationKitLayoutNative labels a kit using the Quarkus native packaging
+	// IntegrationKitLayoutNative labels a kit using the Quarkus native packaging.
 	IntegrationKitLayoutNative = "native"
+	// IntegrationKitLayoutNativeSources labels a kit using the Quarkus native-sources packaging.
+	IntegrationKitLayoutNativeSources = "native-sources"
 
-	// IntegrationKitPriorityLabel labels the kit priority
+	// IntegrationKitPriorityLabel labels the kit priority.
 	IntegrationKitPriorityLabel = "camel.apache.org/kit.priority"
 
-	// IntegrationKitPhaseNone --
+	// IntegrationKitPhaseNone --.
 	IntegrationKitPhaseNone IntegrationKitPhase = ""
-	// IntegrationKitPhaseInitialization --
+	// IntegrationKitPhaseInitialization --.
 	IntegrationKitPhaseInitialization IntegrationKitPhase = "Initialization"
-	// IntegrationKitPhaseWaitingForPlatform --
+	// IntegrationKitPhaseWaitingForPlatform --.
 	IntegrationKitPhaseWaitingForPlatform IntegrationKitPhase = "Waiting For Platform"
-	// IntegrationKitPhaseBuildSubmitted --
+	// IntegrationKitPhaseBuildSubmitted --.
 	IntegrationKitPhaseBuildSubmitted IntegrationKitPhase = "Build Submitted"
-	// IntegrationKitPhaseBuildRunning --
+	// IntegrationKitPhaseBuildRunning --.
 	IntegrationKitPhaseBuildRunning IntegrationKitPhase = "Build Running"
-	// IntegrationKitPhaseWaitingForCatalog --
+	// IntegrationKitPhaseWaitingForCatalog --.
 	IntegrationKitPhaseWaitingForCatalog IntegrationKitPhase = "Waiting For Catalog"
-	// IntegrationKitPhaseReady --
+	// IntegrationKitPhaseReady --.
 	IntegrationKitPhaseReady IntegrationKitPhase = "Ready"
-	// IntegrationKitPhaseError --
+	// IntegrationKitPhaseError --.
 	IntegrationKitPhaseError IntegrationKitPhase = "Error"
 
-	// IntegrationKitConditionPlatformAvailable --
+	// IntegrationKitConditionPlatformAvailable --.
 	IntegrationKitConditionPlatformAvailable IntegrationKitConditionType = "IntegrationPlatformAvailable"
-	// IntegrationKitConditionCatalogAvailable --
+	// IntegrationKitConditionCatalogAvailable --.
 	IntegrationKitConditionCatalogAvailable IntegrationKitConditionType = "CamelCatalogAvailable"
-	// IntegrationKitConditionPlatformAvailableReason --
+	// IntegrationKitConditionPlatformAvailableReason --.
 	IntegrationKitConditionPlatformAvailableReason string = "IntegrationPlatformAvailable"
+	// IntegrationKitConditionTraitInfo --.
+	IntegrationKitConditionTraitInfo IntegrationKitConditionType = "TraitInfo"
 )
 
 // IntegrationKitCondition describes the state of a resource at a certain point.
