@@ -24,6 +24,8 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
+const IntegrationKitLabel = "camel.apache.org/integrationkit"
+
 func NewIntegrationKit(namespace string, name string) *IntegrationKit {
 	return &IntegrationKit{
 		TypeMeta: metav1.TypeMeta{
@@ -54,7 +56,7 @@ func (in *IntegrationKitSpec) Configurations() []ConfigurationSpec {
 	return in.Configuration
 }
 
-// SetOperatorID sets the given operator id as an annotation
+// SetOperatorID sets the given operator id as an annotation.
 func (in *IntegrationKit) SetOperatorID(operatorID string) {
 	SetAnnotation(&in.ObjectMeta, OperatorIDAnnotation, operatorID)
 }
@@ -99,6 +101,22 @@ func (in *IntegrationKit) HasHigherPriorityThan(kit *IntegrationKit) bool {
 	return p1 > p2
 }
 
+// IsExternal returns true for external IntegrationKits (integration kit not created by the operator).
+func (in *IntegrationKit) IsExternal() bool {
+	return in.Labels[IntegrationKitTypeLabel] == IntegrationKitTypeExternal
+}
+
+// HasCapability returns true if the Kit is enabled with such a capability.
+func (in *IntegrationKit) HasCapability(capability string) bool {
+	for _, cap := range in.Spec.Capabilities {
+		if cap == capability {
+			return true
+		}
+	}
+
+	return false
+}
+
 // GetCondition returns the condition with the provided type.
 func (in *IntegrationKitStatus) GetCondition(condType IntegrationKitConditionType) *IntegrationKitCondition {
 	for i := range in.Conditions {
