@@ -33,8 +33,11 @@ import (
 )
 
 const (
-	ContextDir      = "context"
-	DeploymentDir   = "/deployments"
+	// ContextDir is the directory used to package the container.
+	ContextDir = "context"
+	// DeploymentDir is the directory used in the runtime application to deploy the artifacts.
+	DeploymentDir = "/deployments"
+	// DependenciesDir is the directory used to store required dependencies.
 	DependenciesDir = "dependencies"
 )
 
@@ -50,6 +53,7 @@ type imageSteps struct {
 	JvmDockerfile           Step
 }
 
+// Image used to export the steps available on an Image building process.
 var Image = imageSteps{
 	IncrementalImageContext: NewStep(ApplicationPackagePhase, incrementalImageContext),
 	NativeImageContext:      NewStep(ApplicationPackagePhase, nativeImageContext),
@@ -63,17 +67,14 @@ type artifactsSelector func(ctx *builderContext) error
 func nativeImageContext(ctx *builderContext) error {
 	return imageContext(ctx, func(ctx *builderContext) error {
 		runner := "camel-k-integration-" + defaults.Version + "-runner"
-
-		ctx.BaseImage = "quay.io/quarkus/quarkus-distroless-image:1.0"
 		ctx.Artifacts = []v1.Artifact{
 			{
 				ID:       runner,
-				Location: filepath.Join(ctx.Path, "maven", "target", runner),
+				Location: QuarkusRuntimeSupport(ctx.Catalog.GetCamelQuarkusVersion()).TargetDirectory(ctx.Path, runner),
 				Target:   runner,
 			},
 		}
 		ctx.SelectedArtifacts = ctx.Artifacts
-
 		return nil
 	})
 }
@@ -130,6 +131,7 @@ func incrementalImageContext(ctx *builderContext) error {
 
 		bestImage, commonLibs := findBestImage(images, ctx.Artifacts)
 		if bestImage.Image != "" {
+
 			ctx.BaseImage = bestImage.Image
 			ctx.SelectedArtifacts = make([]v1.Artifact, 0)
 
@@ -138,9 +140,6 @@ func incrementalImageContext(ctx *builderContext) error {
 					ctx.SelectedArtifacts = append(ctx.SelectedArtifacts, entry)
 				}
 			}
-		} else if ctx.BaseImage == "" {
-			// TODO: transient workaround to be removed in 1.8.x
-			ctx.BaseImage = defaults.BaseImage()
 		}
 
 		return nil
@@ -180,7 +179,7 @@ func imageContext(ctx *builderContext, selector artifactsSelector) error {
 
 func listPublishedImages(context *builderContext) ([]v1.IntegrationKitStatus, error) {
 	excludeNativeImages, err := labels.NewRequirement(v1.IntegrationKitLayoutLabel, selection.NotEquals, []string{
-		v1.IntegrationKitLayoutNative,
+		v1.IntegrationKitLayoutNativeSources,
 	})
 	if err != nil {
 		return nil, err
@@ -205,13 +204,16 @@ func listPublishedImages(context *builderContext) ([]v1.IntegrationKitStatus, er
 	}
 
 	images := make([]v1.IntegrationKitStatus, 0)
-	for _, item := range list.Items {
-		kit := item
-
+	for _, kit := range list.Items {
+		// Discard non ready kits
 		if kit.Status.Phase != v1.IntegrationKitPhaseReady {
 			continue
 		}
-
+		// Discard kits with a different root hierarchy
+		// context.BaseImage should still contain the root base image at this stage
+		if kit.Status.RootImage != context.BaseImage {
+			continue
+		}
 		images = append(images, kit.Status)
 	}
 	return images, nil
