@@ -24,6 +24,7 @@ import (
 	"strconv"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/apis/camel/v1alpha1"
 
 	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
@@ -41,7 +42,7 @@ func newCmdDelete(rootCmdOptions *RootCmdOptions) (*cobra.Command, *deleteCmdOpt
 	cmd := cobra.Command{
 		Use:     "delete [integration1] [integration2] ...",
 		Short:   "Delete integrations deployed on Kubernetes",
-		PreRunE: decode(&options),
+		PreRunE: decode(&options, options.Flags),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if err := options.validate(args); err != nil {
 				return err
@@ -136,13 +137,22 @@ func getIntegration(ctx context.Context, c client.Client, name string, namespace
 }
 
 func deleteIntegration(ctx context.Context, cmd *cobra.Command, c client.Client, integration *v1.Integration) error {
-	deleted, binding, err := deletePipeIfExists(ctx, c, integration)
+	deletedPipes, pipe, err := deletePipeIfExists(ctx, c, integration)
 	if err != nil {
 		return err
 	}
-	if deleted {
+	if deletedPipes {
 		// Deleting Pipe will automatically clean up the integration
-		fmt.Fprintln(cmd.OutOrStdout(), "Pipe "+binding+" deleted")
+		fmt.Fprintln(cmd.OutOrStdout(), "Pipe "+pipe+" deleted")
+		return nil
+	}
+	deletedKameletBindings, klb, err := deleteKameletBindingIfExists(ctx, c, integration)
+	if err != nil {
+		return err
+	}
+	if deletedKameletBindings {
+		// Deleting KameletBinding will automatically clean up the integration
+		fmt.Fprintln(cmd.OutOrStdout(), "KameletBinding "+klb+" deleted")
 		return nil
 	}
 	return c.Delete(ctx, integration)
@@ -172,6 +182,30 @@ func deletePipeIfExists(ctx context.Context, c client.Client, integration *v1.In
 	return err == nil, name, err
 }
 
+func deleteKameletBindingIfExists(ctx context.Context, c client.Client, integration *v1.Integration) (bool, string, error) {
+	kind, name := findCreator(integration)
+	if kind != v1alpha1.KameletBindingKind || name == "" {
+		return false, "", nil
+	}
+
+	binding := v1alpha1.KameletBinding{
+		TypeMeta: metav1.TypeMeta{
+			Kind:       kind,
+			APIVersion: v1.SchemeGroupVersion.String(),
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Namespace: integration.Namespace,
+			Name:      name,
+		},
+	}
+	err := c.Delete(ctx, &binding)
+	if k8errors.IsNotFound(err) {
+		// Simply skip if binding doesn't exist (could be deleted already)
+		return false, name, nil
+	}
+	return err == nil, name, err
+}
+
 func findCreator(integration *v1.Integration) (string, string) {
 	kind := integration.GetLabels()[kubernetes.CamelCreatorLabelKind]
 	name := integration.GetLabels()[kubernetes.CamelCreatorLabelName]
