@@ -32,9 +32,7 @@ import (
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
-	"github.com/apache/camel-k/v2/pkg/util/defaults"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
-	"github.com/apache/camel-k/v2/pkg/util/maven"
 	"github.com/apache/camel-k/v2/pkg/util/resource"
 	"github.com/magiconair/properties"
 	"github.com/spf13/cobra"
@@ -182,40 +180,13 @@ func validatePropertyFile(fileName string) error {
 	return nil
 }
 
-func createCamelCatalog(ctx context.Context) (*camel.RuntimeCatalog, error) {
+func createCamelCatalog() (*camel.RuntimeCatalog, error) {
 	// Attempt to reuse existing Camel catalog if one is present
 	catalog, err := camel.DefaultCatalog()
 	if err != nil {
 		return nil, err
 	}
 
-	// Generate catalog if one was not found
-	if catalog == nil {
-		catalog, err = generateCatalog(ctx)
-		if err != nil {
-			return nil, err
-		}
-	}
-
-	return catalog, nil
-}
-
-func generateCatalog(ctx context.Context) (*camel.RuntimeCatalog, error) {
-	// A Camel catalog is required for this operation
-	mvn := v1.MavenSpec{
-		LocalRepository: "",
-	}
-	runtime := v1.RuntimeSpec{
-		Version:  defaults.DefaultRuntimeVersion,
-		Provider: v1.RuntimeProviderQuarkus,
-	}
-	var providerDependencies []maven.Dependency
-	var caCert [][]byte
-	catalog, err := camel.GenerateCatalogCommon(ctx, nil, nil, caCert, mvn, runtime, providerDependencies)
-	if err != nil {
-		return nil, err
-	}
-
 	return catalog, nil
 }
 
