@@ -19,6 +19,7 @@ package integration
 
 import (
 	"context"
+	"fmt"
 
 	corev1 "k8s.io/api/core/v1"
 
@@ -51,7 +52,7 @@ func (c *knativeServiceController) getPodSpec() corev1.PodSpec {
 	return c.obj.Spec.Template.Spec.PodSpec
 }
 
-func (c *knativeServiceController) updateReadyCondition(readyPods []corev1.Pod) bool {
+func (c *knativeServiceController) updateReadyCondition(readyPods int) bool {
 	ready := kubernetes.GetKnativeServiceCondition(*c.obj, servingv1.ServiceConditionReady)
 	if ready.IsTrue() {
 		c.integration.SetReadyCondition(corev1.ConditionTrue,
@@ -63,3 +64,11 @@ func (c *knativeServiceController) updateReadyCondition(readyPods []corev1.Pod)
 
 	return false
 }
+
+func (c *knativeServiceController) hasTemplateIntegrationLabel() bool {
+	return c.obj.Spec.Template.Labels[v1.IntegrationLabel] != ""
+}
+
+func (c *knativeServiceController) getControllerName() string {
+	return fmt.Sprintf("KnativeService/%s", c.obj.Name)
+}
