@@ -56,6 +56,13 @@ const (
 	// ReasonIntegrationPlatformError --.
 	ReasonIntegrationPlatformError = "IntegrationPlatformError"
 
+	// ReasonIntegrationProfilePhaseUpdated --.
+	ReasonIntegrationProfilePhaseUpdated = "IntegrationProfilePhaseUpdated"
+	// ReasonIntegrationProfileConditionChanged --.
+	ReasonIntegrationProfileConditionChanged = "IntegrationProfileConditionChanged"
+	// ReasonIntegrationProfileError --.
+	ReasonIntegrationProfileError = "IntegrationProfileError"
+
 	// ReasonBuildPhaseUpdated --.
 	ReasonBuildPhaseUpdated = "BuildPhaseUpdated"
 	// ReasonBuildConditionChanged --.
@@ -168,8 +175,8 @@ func NotifyIntegrationPlatformError(ctx context.Context, c client.Client, record
 	recorder.Eventf(p, corev1.EventTypeWarning, ReasonIntegrationPlatformError, "Cannot reconcile Integration Platform %s: %v", p.Name, err)
 }
 
-// NotifyKameletUpdated automatically generates events when a Kamelet changes.
-func NotifyKameletUpdated(ctx context.Context, c client.Client, recorder record.EventRecorder, old, newResource *v1.Kamelet) {
+// NotifyIntegrationProfileUpdated automatically generates events when a integration profile changes.
+func NotifyIntegrationProfileUpdated(ctx context.Context, c client.Client, recorder record.EventRecorder, old, newResource *v1.IntegrationProfile) {
 	if newResource == nil {
 		return
 	}
@@ -179,22 +186,22 @@ func NotifyKameletUpdated(ctx context.Context, c client.Client, recorder record.
 		oldPhase = string(old.Status.Phase)
 		oldConditions = old.Status.GetConditions()
 	}
-	if newResource.Status.Phase != v1.KameletPhaseNone {
-		notifyIfConditionUpdated(recorder, newResource, oldConditions, newResource.Status.GetConditions(), "Kamelet", newResource.Name, ReasonKameletConditionChanged)
+	if newResource.Status.Phase != v1.IntegrationProfilePhaseNone {
+		notifyIfConditionUpdated(recorder, newResource, oldConditions, newResource.Status.GetConditions(), "Integration Profile", newResource.Name, ReasonIntegrationProfileConditionChanged)
 	}
-	notifyIfPhaseUpdated(ctx, c, recorder, newResource, oldPhase, string(newResource.Status.Phase), "Kamelet", newResource.Name, ReasonKameletPhaseUpdated, "")
+	notifyIfPhaseUpdated(ctx, c, recorder, newResource, oldPhase, string(newResource.Status.Phase), "Integration Profile", newResource.Name, ReasonIntegrationProfilePhaseUpdated, "")
 }
 
-// NotifyKameletError automatically generates error events when the kamelet reconcile cycle phase has an error.
-func NotifyKameletError(ctx context.Context, c client.Client, recorder record.EventRecorder, old, newResource *v1.Kamelet, err error) {
-	k := old
+// NotifyIntegrationProfileError automatically generates error events when the integration Platform reconcile cycle phase has an error.
+func NotifyIntegrationProfileError(ctx context.Context, c client.Client, recorder record.EventRecorder, old, newResource *v1.IntegrationProfile, err error) {
+	p := old
 	if newResource != nil {
-		k = newResource
+		p = newResource
 	}
-	if k == nil {
+	if p == nil {
 		return
 	}
-	recorder.Eventf(k, corev1.EventTypeWarning, ReasonKameletError, "Cannot reconcile Kamelet %s: %v", k.Name, err)
+	recorder.Eventf(p, corev1.EventTypeWarning, ReasonIntegrationProfileError, "Cannot reconcile Integration Profile %s: %v", p.Name, err)
 }
 
 // NotifyCamelCatalogUpdated automatically generates events when a CamelCatalog changes.
