@@ -18,63 +18,61 @@ limitations under the License.
 package trait
 
 import (
-	"context"
 	"errors"
 	"fmt"
 	"strconv"
-	"strings"
 
 	corev1 "k8s.io/api/core/v1"
-	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/runtime/schema"
-	"k8s.io/utils/pointer"
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
-	"github.com/apache/camel-k/v2/pkg/util/maven"
 	"github.com/apache/camel-k/v2/pkg/util/property"
 )
 
+const (
+	CamelPropertiesType = "camel-properties"
+)
+
 type camelTrait struct {
-	BaseTrait
+	BasePlatformTrait
 	traitv1.CamelTrait `property:",squash"`
 }
 
 func newCamelTrait() Trait {
 	return &camelTrait{
-		BaseTrait: NewBaseTrait("camel", 200),
+		BasePlatformTrait: NewBasePlatformTrait("camel", 200),
 	}
 }
 
-// IsPlatformTrait overrides base class method.
-func (t *camelTrait) IsPlatformTrait() bool {
-	return true
-}
-
 // InfluencesKit overrides base class method.
 func (t *camelTrait) InfluencesKit() bool {
 	return true
 }
 
-// InfluencesBuild only when the runtime has changed.
-func (t *camelTrait) InfluencesBuild(this, prev map[string]interface{}) bool {
-	return this["runtimeVersion"] != prev["runtimeVersion"]
+func (t *camelTrait) Matches(trait Trait) bool {
+	otherTrait, ok := trait.(*camelTrait)
+	if !ok {
+		return false
+	}
+
+	return otherTrait.RuntimeVersion == t.RuntimeVersion
 }
 
-func (t *camelTrait) Configure(e *Environment) (bool, error) {
-	if !pointer.BoolDeref(t.Enabled, true) {
-		return false, errors.New("trait camel cannot be disabled")
-	}
-
+func (t *camelTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 	if t.RuntimeVersion == "" {
-		t.RuntimeVersion = determineRuntimeVersion(e)
+		if runtimeVersion, err := determineRuntimeVersion(e); err != nil {
+			return false, nil, err
+		} else {
+			t.RuntimeVersion = runtimeVersion
+		}
 	}
 
-	return true, nil
+	// Don't run this trait for a synthetic Integration
+	return e.Integration == nil || !e.Integration.IsSynthetic(), nil, nil
 }
 
 func (t *camelTrait) Apply(e *Environment) error {
@@ -109,8 +107,8 @@ func (t *camelTrait) Apply(e *Environment) error {
 }
 
 func (t *camelTrait) loadOrCreateCatalog(e *Environment, runtimeVersion string) error {
-	ns := e.DetermineCatalogNamespace()
-	if ns == "" {
+	catalogNamespace := e.DetermineCatalogNamespace()
+	if catalogNamespace == "" {
 		return errors.New("unable to determine namespace")
 	}
 
@@ -119,7 +117,7 @@ func (t *camelTrait) loadOrCreateCatalog(e *Environment, runtimeVersion string)
 		Provider: v1.RuntimeProviderQuarkus,
 	}
 
-	catalog, err := camel.LoadCatalog(e.Ctx, e.Client, ns, runtime)
+	catalog, err := camel.LoadCatalog(e.Ctx, e.Client, catalogNamespace, runtime)
 	if err != nil {
 		return err
 	}
@@ -129,57 +127,10 @@ func (t *camelTrait) loadOrCreateCatalog(e *Environment, runtimeVersion string)
 		// the required versions (camel and runtime) are not expressed as
 		// semver constraints
 		if exactVersionRegexp.MatchString(runtimeVersion) {
-			ctx, cancel := context.WithTimeout(e.Ctx, e.Platform.Status.Build.GetTimeout().Duration)
-			defer cancel()
-			catalog, err = camel.GenerateCatalog(ctx, e.Client,
-				ns, e.Platform.Status.Build.Maven, runtime, []maven.Dependency{})
+			catalog, err = camel.CreateCatalog(e.Ctx, e.Client, catalogNamespace, e.Platform, runtime)
 			if err != nil {
 				return err
 			}
-
-			// sanitize catalog name
-			catalogName := "camel-catalog-" + strings.ToLower(runtimeVersion)
-
-			cx := v1.NewCamelCatalogWithSpecs(ns, catalogName, catalog.CamelCatalogSpec)
-			cx.Labels = make(map[string]string)
-			cx.Labels["app"] = "camel-k"
-			cx.Labels["camel.apache.org/runtime.version"] = runtime.Version
-			cx.Labels["camel.apache.org/runtime.provider"] = string(runtime.Provider)
-			cx.Labels["camel.apache.org/catalog.generated"] = True
-
-			if err := e.Client.Create(e.Ctx, &cx); err != nil {
-				if k8serrors.IsAlreadyExists(err) {
-					// It's still possible that catalog wasn't yet found at the time of loading
-					// but then created in the background before the client tries to create it.
-					// In this case, simply try loading again and reuse the existing catalog.
-					catalog, err = camel.LoadCatalog(e.Ctx, e.Client, ns, runtime)
-					if err != nil {
-						// unexpected error
-						return fmt.Errorf("catalog %q already exists but unable to load: %w", catalogName, err)
-					}
-				} else {
-					return fmt.Errorf("unable to create catalog runtime=%s, provider=%s, name=%s: %w",
-						runtime.Version,
-						runtime.Provider,
-						catalogName, err)
-
-				}
-			}
-
-			// verify that the catalog was generated
-			ct, err := kubernetes.GetUnstructured(
-				e.Ctx,
-				e.Client,
-				schema.GroupVersionKind{Group: "camel.apache.org", Version: "v1", Kind: "CamelCatalog"},
-				catalogName,
-				e.Integration.Namespace,
-			)
-			if ct == nil || err != nil {
-				return fmt.Errorf("unable to create catalog runtime=%s, provider=%s, name=%s: %w",
-					runtime.Version,
-					runtime.Provider,
-					catalogName, err)
-			}
 		}
 	}
 
@@ -195,7 +146,7 @@ func (t *camelTrait) loadOrCreateCatalog(e *Environment, runtimeVersion string)
 }
 
 func (t *camelTrait) computeConfigMaps(e *Environment) []ctrl.Object {
-	sources := e.Integration.Sources()
+	sources := e.Integration.AllSources()
 	maps := make([]ctrl.Object, 0, len(sources)+1)
 
 	// combine properties of integration with kit, integration
@@ -229,6 +180,7 @@ func (t *camelTrait) computeConfigMaps(e *Environment) []ctrl.Object {
 					Labels: map[string]string{
 						v1.IntegrationLabel:                e.Integration.Name,
 						"camel.apache.org/properties.type": "user",
+						kubernetes.ConfigMapTypeLabel:      CamelPropertiesType,
 					},
 				},
 				Data: map[string]string{
@@ -238,8 +190,9 @@ func (t *camelTrait) computeConfigMaps(e *Environment) []ctrl.Object {
 		)
 	}
 
-	for i, s := range sources {
-		if s.ContentRef != "" || e.isEmbedded(s) {
+	i := 0
+	for _, s := range sources {
+		if s.ContentRef != "" || e.isEmbedded(s) || s.IsGeneratedFromKamelet() {
 			continue
 		}
 
@@ -255,10 +208,10 @@ func (t *camelTrait) computeConfigMaps(e *Environment) []ctrl.Object {
 					v1.IntegrationLabel: e.Integration.Name,
 				},
 				Annotations: map[string]string{
-					"camel.apache.org/source.language":    string(s.InferLanguage()),
-					"camel.apache.org/source.loader":      s.Loader,
-					"camel.apache.org/source.name":        s.Name,
-					"camel.apache.org/source.compression": strconv.FormatBool(s.Compression),
+					sourceLanguageAnnotation:    string(s.InferLanguage()),
+					sourceLoaderAnnotation:      s.Loader,
+					sourceNameAnnotation:        s.Name,
+					sourceCompressionAnnotation: strconv.FormatBool(s.Compression),
 				},
 			},
 			Data: map[string]string{
@@ -267,20 +220,24 @@ func (t *camelTrait) computeConfigMaps(e *Environment) []ctrl.Object {
 		}
 
 		maps = append(maps, &cm)
+		i++
 	}
 
 	return maps
 }
 
-func determineRuntimeVersion(e *Environment) string {
+func determineRuntimeVersion(e *Environment) (string, error) {
 	if e.Integration != nil && e.Integration.Status.RuntimeVersion != "" {
-		return e.Integration.Status.RuntimeVersion
+		return e.Integration.Status.RuntimeVersion, nil
 	}
 	if e.IntegrationKit != nil && e.IntegrationKit.Status.RuntimeVersion != "" {
-		return e.IntegrationKit.Status.RuntimeVersion
+		return e.IntegrationKit.Status.RuntimeVersion, nil
+	}
+	if e.IntegrationProfile != nil && e.IntegrationProfile.Status.Build.RuntimeVersion != "" {
+		return e.IntegrationProfile.Status.Build.RuntimeVersion, nil
 	}
 	if e.Platform != nil && e.Platform.Status.Build.RuntimeVersion != "" {
-		return e.Platform.Status.Build.RuntimeVersion
+		return e.Platform.Status.Build.RuntimeVersion, nil
 	}
-	return ""
+	return "", errors.New("unable to determine runtime version")
 }
