@@ -23,42 +23,36 @@ import (
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/utils/pointer"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/test"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestConfigureEnabledCamelTraitSucceeds(t *testing.T) {
 	trait, environment := createNominalCamelTest(false)
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, configured)
 }
 
-func TestConfigureDisabledCamelTraitFails(t *testing.T) {
-	trait, environment := createNominalCamelTest(false)
-	trait.Enabled = pointer.Bool(false)
-
-	configured, err := trait.Configure(environment)
-	assert.NotNil(t, err)
-	assert.False(t, configured)
-}
-
 func TestApplyCamelTraitSucceeds(t *testing.T) {
 	trait, environment := createNominalCamelTest(false)
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, configured)
 
 	err = trait.Apply(environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "0.0.1", environment.RuntimeVersion)
 	assert.Equal(t, "0.0.1", environment.Integration.Status.RuntimeVersion)
 	assert.Equal(t, "0.0.1", environment.IntegrationKit.Status.RuntimeVersion)
@@ -75,12 +69,13 @@ func TestApplyCamelTraitWithoutEnvironmentCatalogAndUnmatchableVersionFails(t *t
 	environment.Integration.Status.RuntimeVersion = "Unmatchable version"
 	environment.Integration.Status.RuntimeProvider = v1.RuntimeProviderQuarkus
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, configured)
 
 	err = trait.Apply(environment)
-	assert.NotNil(t, err)
+	require.Error(t, err)
 	assert.Equal(t, "unable to find catalog matching version requirement: runtime=Unmatchable version, provider=quarkus", err.Error())
 }
 
@@ -88,7 +83,6 @@ func createNominalCamelTest(withSources bool) (*camelTrait, *Environment) {
 	client, _ := test.NewFakeClient()
 
 	trait, _ := newCamelTrait().(*camelTrait)
-	trait.Enabled = pointer.Bool(true)
 	var sources []v1.SourceSpec
 	if withSources {
 		sources = []v1.SourceSpec{
@@ -154,7 +148,7 @@ func createNominalCamelTest(withSources bool) (*camelTrait, *Environment) {
 		IntegrationKit: &v1.IntegrationKit{
 			ObjectMeta: metav1.ObjectMeta{
 				Labels: map[string]string{
-					v1.IntegrationKitLayoutLabel: v1.IntegrationKitLayoutNative,
+					v1.IntegrationKitLayoutLabel: v1.IntegrationKitLayoutNativeSources,
 				},
 				Namespace: "namespace",
 			},
@@ -178,12 +172,13 @@ func TestApplyCamelTraitWithProperties(t *testing.T) {
 	trait, environment := createNominalCamelTest(false)
 	trait.Properties = []string{"a=b", "c=d"}
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, configured)
 
 	err = trait.Apply(environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	userPropertiesCm := environment.Resources.GetConfigMap(func(cm *corev1.ConfigMap) bool {
 		return cm.Labels["camel.apache.org/properties.type"] == "user"
@@ -197,19 +192,41 @@ func TestApplyCamelTraitWithProperties(t *testing.T) {
 func TestApplyCamelTraitWithSources(t *testing.T) {
 	trait, environment := createNominalCamelTest(true)
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, configured)
 
 	err = trait.Apply(environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	assert.Equal(t, 1, environment.Resources.Size())
 	sourceCm := environment.Resources.GetConfigMap(func(cm *corev1.ConfigMap) bool {
-		return cm.Name == "some-integration-source-001" && cm.Annotations["camel.apache.org/source.language"] == "xml" && cm.Annotations["camel.apache.org/source.name"] == "source2.xml"
+		return cm.Name == "some-integration-source-000" && cm.Annotations[sourceLanguageAnnotation] == "xml" && cm.Annotations[sourceNameAnnotation] == "source2.xml"
 	})
 	assert.NotNil(t, sourceCm)
 	assert.Equal(t, map[string]string{
 		"content": "XML Source Code",
 	}, sourceCm.Data)
 }
+
+func TestCamelMatches(t *testing.T) {
+	t1 := camelTrait{
+		BasePlatformTrait: NewBasePlatformTrait("camel", 600),
+		CamelTrait: traitv1.CamelTrait{
+			RuntimeVersion: "1.2.3",
+		},
+	}
+	t2 := camelTrait{
+		BasePlatformTrait: NewBasePlatformTrait("camel", 600),
+		CamelTrait: traitv1.CamelTrait{
+			RuntimeVersion: "1.2.3",
+		},
+	}
+
+	assert.True(t, t1.Matches(&t2))
+	t1.Properties = []string{"hello=world"}
+	assert.True(t, t1.Matches(&t2))
+	t2.RuntimeVersion = "3.2.1"
+	assert.False(t, t1.Matches(&t2))
+}
