@@ -39,6 +39,7 @@ import (
 	"github.com/apache/camel-k/v2/pkg/util/envvar"
 	"github.com/apache/camel-k/v2/pkg/util/knative"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/openshift"
 )
 
 const (
@@ -50,13 +51,13 @@ const (
 )
 
 type containerTrait struct {
-	BaseTrait
+	BasePlatformTrait
 	traitv1.ContainerTrait `property:",squash"`
 }
 
 func newContainerTrait() Trait {
 	return &containerTrait{
-		BaseTrait: NewBaseTrait(containerTraitID, 1600),
+		BasePlatformTrait: NewBasePlatformTrait(containerTraitID, 1600),
 		ContainerTrait: traitv1.ContainerTrait{
 			Port:            defaultContainerPort,
 			ServicePort:     defaultServicePort,
@@ -66,33 +67,33 @@ func newContainerTrait() Trait {
 	}
 }
 
-func (t *containerTrait) Configure(e *Environment) (bool, error) {
-	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
-		return false, nil
+func (t *containerTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	if e.Integration == nil {
+		return false, nil, nil
 	}
 
 	if !e.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !e.IntegrationInRunningPhases() {
-		return false, nil
+		return false, nil, nil
 	}
 
-	knativeInstalled, _ := knative.IsInstalled(e.Client)
+	knativeInstalled, _ := knative.IsEventingInstalled(e.Client)
 	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !knativeInstalled {
 		hasKnativeEndpoint, err := containsEndpoint("knative", e, t.Client)
 		if err != nil {
-			return false, err
+			return false, nil, err
 		}
 
 		if hasKnativeEndpoint {
 			// fail fast the integration as there is no knative installed in the cluster
 			t.L.ForIntegration(e.Integration).Infof("Integration %s/%s contains knative endpoint that cannot run, as knative is not installed in the cluster.", e.Integration.Namespace, e.Integration.Name)
 			err := errors.New("integration cannot run, as knative is not installed in the cluster")
-			e.Integration.Status.SetCondition(
+			return false, NewIntegrationCondition(
+				"Container",
 				v1.IntegrationConditionKnativeAvailable,
 				corev1.ConditionFalse,
 				v1.IntegrationConditionKnativeNotInstalledReason,
-				err.Error())
-			e.Integration.Status.Phase = v1.IntegrationPhaseError
-			return false, err
+				err.Error(),
+			), err
 		}
 	}
 
@@ -104,10 +105,10 @@ func (t *containerTrait) Configure(e *Environment) (bool, error) {
 	}
 
 	if !isValidPullPolicy(t.ImagePullPolicy) {
-		return false, fmt.Errorf("unsupported pull policy %s", t.ImagePullPolicy)
+		return false, nil, fmt.Errorf("unsupported pull policy %s", t.ImagePullPolicy)
 	}
 
-	return true, nil
+	return true, nil, nil
 }
 
 func isValidPullPolicy(policy corev1.PullPolicy) bool {
@@ -121,11 +122,6 @@ func (t *containerTrait) Apply(e *Environment) error {
 	return t.configureContainer(e)
 }
 
-// IsPlatformTrait overrides base class method.
-func (t *containerTrait) IsPlatformTrait() bool {
-	return true
-}
-
 func (t *containerTrait) configureImageIntegrationKit(e *Environment) error {
 	if t.Image != "" {
 		if e.Integration.Spec.IntegrationKit != nil {
@@ -151,6 +147,19 @@ func (t *containerTrait) configureImageIntegrationKit(e *Environment) error {
 		if v, ok := e.Integration.Annotations[v1.PlatformSelectorAnnotation]; ok {
 			v1.SetAnnotation(&kit.ObjectMeta, v1.PlatformSelectorAnnotation, v)
 		}
+
+		if v, ok := e.Integration.Annotations[v1.IntegrationProfileAnnotation]; ok {
+			v1.SetAnnotation(&kit.ObjectMeta, v1.IntegrationProfileAnnotation, v)
+
+			if v, ok := e.Integration.Annotations[v1.IntegrationProfileNamespaceAnnotation]; ok {
+				v1.SetAnnotation(&kit.ObjectMeta, v1.IntegrationProfileNamespaceAnnotation, v)
+			} else {
+				// set integration profile namespace to the integration namespace.
+				// this is because the kit may live in another namespace and needs to resolve the integration profile from the integration namespace.
+				v1.SetAnnotation(&kit.ObjectMeta, v1.IntegrationProfileNamespaceAnnotation, e.Integration.Namespace)
+			}
+		}
+
 		operatorID := defaults.OperatorID()
 		if operatorID != "" {
 			kit.SetOperatorID(operatorID)
@@ -167,55 +176,36 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 	if e.ApplicationProperties == nil {
 		e.ApplicationProperties = make(map[string]string)
 	}
-
 	container := corev1.Container{
 		Name:  t.Name,
 		Image: e.Integration.Status.Image,
 		Env:   make([]corev1.EnvVar, 0),
 	}
-
 	if t.ImagePullPolicy != "" {
 		container.ImagePullPolicy = t.ImagePullPolicy
 	}
-
 	// combine Environment of integration with platform, kit, integration
 	for _, env := range e.collectConfigurationPairs("env") {
 		envvar.SetVal(&container.Env, env.Name, env.Value)
 	}
-
 	envvar.SetVal(&container.Env, digest.IntegrationDigestEnvVar, e.Integration.Status.Digest)
 	envvar.SetVal(&container.Env, "CAMEL_K_CONF", filepath.Join(camel.BasePath, "application.properties"))
 	envvar.SetVal(&container.Env, "CAMEL_K_CONF_D", camel.ConfDPath)
 
-	e.addSourcesProperties()
-	if props, err := e.computeApplicationProperties(); err != nil {
-		return err
-	} else if props != nil {
-		e.Resources.Add(props)
-	}
-
-	t.configureResources(&container)
-	if pointer.BoolDeref(t.Expose, false) {
-		t.configureService(e, &container)
-	}
-	t.configureCapabilities(e)
-
 	var containers *[]corev1.Container
 	visited := false
-
+	knative := false
 	// Deployment
 	if err := e.Resources.VisitDeploymentE(func(deployment *appsv1.Deployment) error {
 		for _, envVar := range e.EnvVars {
 			envvar.SetVar(&container.Env, envVar)
 		}
-
 		containers = &deployment.Spec.Template.Spec.Containers
 		visited = true
 		return nil
 	}); err != nil {
 		return err
 	}
-
 	// Knative Service
 	if err := e.Resources.VisitKnativeServiceE(func(service *serving.Service) error {
 		for _, env := range e.EnvVars {
@@ -225,34 +215,43 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 			case env.ValueFrom.FieldRef != nil && env.ValueFrom.FieldRef.FieldPath == "metadata.namespace":
 				envvar.SetVar(&container.Env, corev1.EnvVar{Name: env.Name, Value: e.Integration.Namespace})
 			case env.ValueFrom.FieldRef != nil:
-				t.L.Infof("Skipping environment variable %s (fieldRef)", env.Name)
+				t.L.Debugf("Skipping environment variable %s (fieldRef)", env.Name)
 			case env.ValueFrom.ResourceFieldRef != nil:
-				t.L.Infof("Skipping environment variable %s (resourceFieldRef)", env.Name)
+				t.L.Debugf("Skipping environment variable %s (resourceFieldRef)", env.Name)
 			default:
 				envvar.SetVar(&container.Env, env)
 			}
 		}
-
 		containers = &service.Spec.ConfigurationSpec.Template.Spec.Containers
 		visited = true
+		knative = true
 		return nil
 	}); err != nil {
 		return err
 	}
-
 	// CronJob
 	if err := e.Resources.VisitCronJobE(func(cron *batchv1.CronJob) error {
 		for _, envVar := range e.EnvVars {
 			envvar.SetVar(&container.Env, envVar)
 		}
-
 		containers = &cron.Spec.JobTemplate.Spec.Template.Spec.Containers
 		visited = true
 		return nil
 	}); err != nil {
 		return err
 	}
-
+	e.addSourcesProperties()
+	if props, err := e.computeApplicationProperties(); err != nil {
+		return err
+	} else if props != nil {
+		e.Resources.Add(props)
+	}
+	t.configureResources(&container)
+	if knative || pointer.BoolDeref(t.Expose, false) {
+		t.configureService(e, &container, knative)
+	}
+	t.configureCapabilities(e)
+	t.configureSecurityContext(e, &container)
 	if visited {
 		*containers = append(*containers, container)
 	}
@@ -260,46 +259,42 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 	return nil
 }
 
-func (t *containerTrait) configureService(e *Environment, container *corev1.Container) {
-	service := e.Resources.GetServiceForIntegration(e.Integration)
-	if service == nil {
-		return
-	}
-
+func (t *containerTrait) configureService(e *Environment, container *corev1.Container, isKnative bool) {
 	name := t.PortName
 	if name == "" {
 		name = defaultContainerPortName
 	}
-
 	containerPort := corev1.ContainerPort{
-		Name:          name,
 		ContainerPort: int32(t.Port),
 		Protocol:      corev1.ProtocolTCP,
 	}
-
-	servicePort := corev1.ServicePort{
-		Name:       t.ServicePortName,
-		Port:       int32(t.ServicePort),
-		Protocol:   corev1.ProtocolTCP,
-		TargetPort: intstr.FromString(name),
+	if !isKnative {
+		// Knative does not want name=http
+		containerPort.Name = name
+		// The service is managed by Knative, so, we only take care of this when it's managed by us
+		service := e.Resources.GetServiceForIntegration(e.Integration)
+		if service != nil {
+			servicePort := corev1.ServicePort{
+				Name:       t.ServicePortName,
+				Port:       int32(t.ServicePort),
+				Protocol:   corev1.ProtocolTCP,
+				TargetPort: intstr.FromString(name),
+			}
+			e.Integration.Status.SetCondition(
+				v1.IntegrationConditionServiceAvailable,
+				corev1.ConditionTrue,
+				v1.IntegrationConditionServiceAvailableReason,
+				// service -> container
+				fmt.Sprintf("%s(%s/%d) -> %s(%s/%d)",
+					service.Name, servicePort.Name, servicePort.Port,
+					container.Name, containerPort.Name, containerPort.ContainerPort),
+			)
+			service.Spec.Ports = append(service.Spec.Ports, servicePort)
+			// Mark the service as a user service
+			service.Labels["camel.apache.org/service.type"] = v1.ServiceTypeUser
+		}
 	}
-
-	e.Integration.Status.SetCondition(
-		v1.IntegrationConditionServiceAvailable,
-		corev1.ConditionTrue,
-		v1.IntegrationConditionServiceAvailableReason,
-
-		// service -> container
-		fmt.Sprintf("%s(%s/%d) -> %s(%s/%d)",
-			service.Name, servicePort.Name, servicePort.Port,
-			container.Name, containerPort.Name, containerPort.ContainerPort),
-	)
-
 	container.Ports = append(container.Ports, containerPort)
-	service.Spec.Ports = append(service.Spec.Ports, servicePort)
-
-	// Mark the service as a user service
-	service.Labels["camel.apache.org/service.type"] = v1.ServiceTypeUser
 }
 
 func (t *containerTrait) configureResources(container *corev1.Container) {
@@ -339,3 +334,14 @@ func (t *containerTrait) configureCapabilities(e *Environment) {
 		e.ApplicationProperties["camel.context.rest-configuration.component"] = "platform-http"
 	}
 }
+
+func (t *containerTrait) configureSecurityContext(e *Environment, container *corev1.Container) {
+	// get security context from security context constraint configuration in namespace
+	isOpenShift, _ := openshift.IsOpenShift(e.Client)
+	if isOpenShift {
+		securityContext, _ := openshift.GetOpenshiftSecurityContextRestricted(e.Ctx, e.Client, e.Integration.Namespace)
+		if securityContext != nil {
+			container.SecurityContext = securityContext
+		}
+	}
+}
