@@ -21,6 +21,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/utils/pointer"
@@ -36,7 +37,7 @@ func newTestProbesEnv(t *testing.T, integration *v1.Integration) Environment {
 	t.Helper()
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, catalog)
 
 	client, _ := test.NewFakeClient()
@@ -78,9 +79,9 @@ func TestProbesDependencies(t *testing.T) {
 	env := newTestProbesEnv(t, integration)
 	env.Integration.Status.Phase = v1.IntegrationPhaseInitialization
 
-	err := env.Catalog.apply(&env)
-	assert.Nil(t, err)
-
+	conditions, err := env.Catalog.apply(&env)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.Contains(t, env.Integration.Status.Dependencies, "mvn:org.apache.camel.quarkus:camel-quarkus-microprofile-health")
 }
 
@@ -103,8 +104,9 @@ func TestProbesOnDeployment(t *testing.T) {
 	env := newTestProbesEnv(t, integration)
 	env.Integration.Status.Phase = v1.IntegrationPhaseDeploying
 
-	err := env.Catalog.apply(&env)
-	assert.Nil(t, err)
+	conditions, err := env.Catalog.apply(&env)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 
 	container := env.GetIntegrationContainer()
 
@@ -140,8 +142,9 @@ func TestProbesOnDeploymentWithCustomScheme(t *testing.T) {
 	env := newTestProbesEnv(t, integration)
 	env.Integration.Status.Phase = v1.IntegrationPhaseDeploying
 
-	err := env.Catalog.apply(&env)
-	assert.Nil(t, err)
+	conditions, err := env.Catalog.apply(&env)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 
 	container := env.GetIntegrationContainer()
 
@@ -181,8 +184,25 @@ func TestProbesOnKnativeService(t *testing.T) {
 	env := newTestProbesEnv(t, integration)
 	env.Integration.Status.Phase = v1.IntegrationPhaseDeploying
 
-	err := env.Catalog.apply(&env)
-	assert.Nil(t, err)
+	serviceOverrideCondition := NewIntegrationCondition(
+		"Service",
+		v1.IntegrationConditionTraitInfo,
+		corev1.ConditionTrue,
+		"TraitConfiguration",
+		"explicitly disabled by the platform: knative-service trait has priority over this trait",
+	)
+	ctrlStrategyCondition := NewIntegrationCondition(
+		"Deployment",
+		v1.IntegrationConditionDeploymentAvailable,
+		corev1.ConditionFalse,
+		"DeploymentAvailable",
+		"controller strategy: knative-service",
+	)
+
+	conditions, err := env.Catalog.apply(&env)
+	require.NoError(t, err)
+	assert.Contains(t, conditions, ctrlStrategyCondition)
+	assert.Contains(t, conditions, serviceOverrideCondition)
 
 	container := env.GetIntegrationContainer()
 
