@@ -23,6 +23,7 @@ import (
 
 	"github.com/google/uuid"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -40,7 +41,7 @@ import (
 
 func TestContainerWithDefaults(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	client, _ := test.NewFakeClient()
 	traitCatalog := NewCatalog(nil)
@@ -85,9 +86,10 @@ func TestContainerWithDefaults(t *testing.T) {
 	}
 	environment.Platform.ResyncStatusFullConfig()
 
-	err = traitCatalog.apply(&environment)
+	conditions, err := traitCatalog.apply(&environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("deployment"))
 	assert.NotNil(t, environment.GetTrait("container"))
@@ -99,13 +101,95 @@ func TestContainerWithDefaults(t *testing.T) {
 	assert.Equal(t, defaultContainerName, d.Spec.Template.Spec.Containers[0].Name)
 }
 
+func TestContainerWithOpenshift(t *testing.T) {
+	catalog, err := camel.DefaultCatalog()
+	require.NoError(t, err)
+
+	// Integration is in another constrained namespace
+	constrainedIntNamespace := &corev1.Namespace{
+		ObjectMeta: metav1.ObjectMeta{
+			Name: "myuser",
+			Annotations: map[string]string{
+				"openshift.io/sa.scc.mcs":                 "s0:c26,c5",
+				"openshift.io/sa.scc.supplemental-groups": "1000860000/10000",
+				"openshift.io/sa.scc.uid-range":           "1000860000/10000",
+			},
+		},
+	}
+
+	client, _ := test.NewFakeClient(constrainedIntNamespace)
+	traitCatalog := NewCatalog(nil)
+
+	// enable openshift
+	fakeClient := client.(*test.FakeClient) //nolint
+	fakeClient.EnableOpenshiftDiscovery()
+
+	environment := Environment{
+		CamelCatalog: catalog,
+		Catalog:      traitCatalog,
+		Client:       client,
+		Integration: &v1.Integration{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      ServiceTestName,
+				Namespace: "myuser",
+			},
+			Status: v1.IntegrationStatus{
+				Phase: v1.IntegrationPhaseDeploying,
+			},
+			Spec: v1.IntegrationSpec{
+				Profile: v1.TraitProfileKubernetes,
+			},
+		},
+		IntegrationKit: &v1.IntegrationKit{
+			Status: v1.IntegrationKitStatus{
+				Phase: v1.IntegrationKitPhaseReady,
+			},
+		},
+		Platform: &v1.IntegrationPlatform{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "ns",
+			},
+			Spec: v1.IntegrationPlatformSpec{
+				Cluster: v1.IntegrationPlatformClusterOpenShift,
+				Build: v1.IntegrationPlatformBuildSpec{
+					PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
+					Registry:        v1.RegistrySpec{Address: "registry"},
+					RuntimeVersion:  catalog.Runtime.Version,
+				},
+			},
+			Status: v1.IntegrationPlatformStatus{
+				Phase: v1.IntegrationPlatformPhaseReady,
+			},
+		},
+		EnvVars:        make([]corev1.EnvVar, 0),
+		ExecutedTraits: make([]Trait, 0),
+		Resources:      kubernetes.NewCollection(),
+	}
+	environment.Platform.ResyncStatusFullConfig()
+
+	conditions, err := traitCatalog.apply(&environment)
+
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
+	assert.NotEmpty(t, environment.ExecutedTraits)
+	assert.NotNil(t, environment.GetTrait("deployment"))
+	assert.NotNil(t, environment.GetTrait("container"))
+
+	d := environment.Resources.GetDeploymentForIntegration(environment.Integration)
+
+	assert.NotNil(t, d)
+	assert.Len(t, d.Spec.Template.Spec.Containers, 1)
+	assert.Equal(t, defaultContainerName, d.Spec.Template.Spec.Containers[0].Name)
+	assert.Equal(t, pointer.Bool(true), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsNonRoot)
+	assert.Equal(t, pointer.Int64(1000860000), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser)
+}
+
 func TestContainerWithCustomName(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	client, _ := test.NewFakeClient()
 	traitCatalog := NewCatalog(nil)
-
 	environment := Environment{
 		CamelCatalog: catalog,
 		Catalog:      traitCatalog,
@@ -151,9 +235,10 @@ func TestContainerWithCustomName(t *testing.T) {
 	}
 	environment.Platform.ResyncStatusFullConfig()
 
-	err = traitCatalog.apply(&environment)
+	conditions, err := traitCatalog.apply(&environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("deployment"))
 	assert.NotNil(t, environment.GetTrait("container"))
@@ -169,7 +254,7 @@ func TestContainerWithCustomName(t *testing.T) {
 
 func TestContainerWithCustomImage(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	client, _ := test.NewFakeClient()
 	traitCatalog := NewCatalog(nil)
@@ -216,11 +301,13 @@ func TestContainerWithCustomImage(t *testing.T) {
 	}
 	environment.Platform.ResyncStatusFullConfig()
 
-	err = traitCatalog.apply(&environment)
-	assert.Nil(t, err)
+	conditions, err := traitCatalog.apply(&environment)
+
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 
 	for _, postAction := range environment.PostActions {
-		assert.Nil(t, postAction(&environment))
+		require.NoError(t, postAction(&environment))
 	}
 
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -235,7 +322,7 @@ func TestContainerWithCustomImage(t *testing.T) {
 	}
 
 	err = client.Get(context.TODO(), key, &ikt)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, environment.Integration.ObjectMeta.UID, ikt.ObjectMeta.OwnerReferences[0].UID)
 
 	trait := environment.Integration.Spec.Traits.Container
@@ -244,7 +331,7 @@ func TestContainerWithCustomImage(t *testing.T) {
 
 func TestContainerWithCustomImageAndIntegrationKit(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	client, _ := test.NewFakeClient()
 	traitCatalog := NewCatalog(nil)
@@ -295,14 +382,15 @@ func TestContainerWithCustomImageAndIntegrationKit(t *testing.T) {
 	}
 	environment.Platform.ResyncStatusFullConfig()
 
-	err = traitCatalog.apply(&environment)
-	assert.NotNil(t, err)
+	conditions, err := traitCatalog.apply(&environment)
+	require.Error(t, err)
+	assert.Empty(t, conditions)
 	assert.Contains(t, err.Error(), "unsupported configuration: a container image has been set in conjunction with an IntegrationKit")
 }
 
 func TestContainerWithImagePullPolicy(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	client, _ := test.NewFakeClient()
 	traitCatalog := NewCatalog(nil)
@@ -337,8 +425,10 @@ func TestContainerWithImagePullPolicy(t *testing.T) {
 	environment.Integration.Status.Phase = v1.IntegrationPhaseDeploying
 	environment.Platform.ResyncStatusFullConfig()
 
-	err = traitCatalog.apply(&environment)
-	assert.Nil(t, err)
+	conditions, err := traitCatalog.apply(&environment)
+
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 
 	container := environment.GetIntegrationContainer()
 
@@ -346,12 +436,8 @@ func TestContainerWithImagePullPolicy(t *testing.T) {
 }
 
 func TestRunKnativeEndpointWithKnativeNotInstalled(t *testing.T) {
-
 	environment := createEnvironment()
-
 	trait, _ := newContainerTrait().(*containerTrait)
-	trait.Enabled = pointer.Bool(true)
-
 	environment.Integration.Spec.Sources = []v1.SourceSpec{
 		{
 			DataSpec: v1.DataSpec{
@@ -363,19 +449,23 @@ func TestRunKnativeEndpointWithKnativeNotInstalled(t *testing.T) {
 			Language: v1.LanguageJavaSource,
 		},
 	}
-	configured, err := trait.Configure(environment)
-	assert.NotNil(t, err)
+	expectedCondition := NewIntegrationCondition(
+		"Container",
+		v1.IntegrationConditionKnativeAvailable,
+		corev1.ConditionFalse,
+		v1.IntegrationConditionKnativeNotInstalledReason,
+		"integration cannot run, as knative is not installed in the cluster",
+	)
+	configured, condition, err := trait.Configure(environment)
+	require.Error(t, err)
+	assert.Equal(t, expectedCondition, condition)
 	assert.False(t, configured)
-	conditions := environment.Integration.Status.Conditions
-	assert.Len(t, conditions, 1)
-	assert.Equal(t, v1.IntegrationConditionKnativeNotInstalledReason, conditions[0].Reason)
 }
 
 func TestRunNonKnativeEndpointWithKnativeNotInstalled(t *testing.T) {
 
 	environment := createEnvironment()
 	trait, _ := newContainerTrait().(*containerTrait)
-	trait.Enabled = pointer.Bool(true)
 	environment.Integration.Spec.Sources = []v1.SourceSpec{
 		{
 			DataSpec: v1.DataSpec{
@@ -388,19 +478,20 @@ func TestRunNonKnativeEndpointWithKnativeNotInstalled(t *testing.T) {
 		},
 	}
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, configured)
 	conditions := environment.Integration.Status.Conditions
-	assert.Len(t, conditions, 0)
+	assert.Empty(t, conditions)
 }
 
 func createEnvironment() *Environment {
 
 	client, _ := test.NewFakeClient()
-	// disable the knative service api
+	// disable the knative eventing api
 	fakeClient := client.(*test.FakeClient) //nolint
-	fakeClient.DisableAPIGroupDiscovery("serving.knative.dev/v1")
+	fakeClient.DisableAPIGroupDiscovery("eventing.knative.dev/v1")
 
 	replicas := int32(3)
 	catalog, _ := camel.QuarkusCatalog()
@@ -437,3 +528,130 @@ func createEnvironment() *Environment {
 
 	return environment
 }
+
+func TestDeploymentContainerPorts(t *testing.T) {
+	catalog, err := camel.DefaultCatalog()
+	require.NoError(t, err)
+
+	client, _ := test.NewFakeClient()
+	traitCatalog := NewCatalog(nil)
+
+	environment := Environment{
+		Ctx:          context.TODO(),
+		Client:       client,
+		CamelCatalog: catalog,
+		Catalog:      traitCatalog,
+		Integration: &v1.Integration{
+			Spec: v1.IntegrationSpec{
+				Profile: v1.TraitProfileKubernetes,
+				Traits: v1.Traits{
+					Container: &traitv1.ContainerTrait{
+						Port:        8081,
+						ServicePort: 8081,
+					},
+				},
+				Sources: []v1.SourceSpec{
+					{
+						Language: v1.LanguageJavaSource,
+						DataSpec: v1.DataSpec{
+							Name: "MyTest.java",
+							Content: `
+							public class MyRouteBuilder extends RouteBuilder {
+								@Override
+								public void configure() throws Exception {
+									from("netty-http:http://0.0.0.0:8081/hello").log("Received message: ${body}");
+								}
+							}
+							`,
+						},
+					},
+				},
+			},
+		},
+		Platform: &v1.IntegrationPlatform{
+			Spec: v1.IntegrationPlatformSpec{
+				Build: v1.IntegrationPlatformBuildSpec{
+					RuntimeVersion: catalog.Runtime.Version,
+				},
+			},
+			Status: v1.IntegrationPlatformStatus{
+				Phase: v1.IntegrationPlatformPhaseReady,
+			},
+		},
+		Resources: kubernetes.NewCollection(),
+	}
+	environment.Integration.Status.Phase = v1.IntegrationPhaseDeploying
+	environment.Platform.ResyncStatusFullConfig()
+
+	_, err = traitCatalog.apply(&environment)
+	require.NoError(t, err)
+	container := environment.GetIntegrationContainer()
+	assert.Len(t, container.Ports, 1)
+	assert.Equal(t, int32(8081), container.Ports[0].ContainerPort)
+	assert.Equal(t, "http", container.Ports[0].Name)
+	svc := environment.Resources.GetServiceForIntegration(environment.Integration)
+	assert.Len(t, svc.Spec.Ports, 1)
+	assert.Equal(t, int32(8081), svc.Spec.Ports[0].Port)
+}
+
+func TestKnativeServiceContainerPorts(t *testing.T) {
+	catalog, err := camel.DefaultCatalog()
+	require.NoError(t, err)
+
+	client, _ := test.NewFakeClient()
+	traitCatalog := NewCatalog(nil)
+
+	environment := Environment{
+		Ctx:          context.TODO(),
+		Client:       client,
+		CamelCatalog: catalog,
+		Catalog:      traitCatalog,
+		Integration: &v1.Integration{
+			Spec: v1.IntegrationSpec{
+				Profile: v1.TraitProfileKnative,
+				Traits: v1.Traits{
+					Container: &traitv1.ContainerTrait{
+						Port:        8081,
+						ServicePort: 8081,
+					},
+				},
+				Sources: []v1.SourceSpec{
+					{
+						Language: v1.LanguageJavaSource,
+						DataSpec: v1.DataSpec{
+							Name: "MyTest.java",
+							Content: `
+							public class MyRouteBuilder extends RouteBuilder {
+								@Override
+								public void configure() throws Exception {
+									from("netty-http:http://0.0.0.0:8081/hello").log("Received message: ${body}");
+								}
+							}
+							`,
+						},
+					},
+				},
+			},
+		},
+		Platform: &v1.IntegrationPlatform{
+			Spec: v1.IntegrationPlatformSpec{
+				Build: v1.IntegrationPlatformBuildSpec{
+					RuntimeVersion: catalog.Runtime.Version,
+				},
+			},
+			Status: v1.IntegrationPlatformStatus{
+				Phase: v1.IntegrationPlatformPhaseReady,
+			},
+		},
+		Resources: kubernetes.NewCollection(),
+	}
+	environment.Integration.Status.Phase = v1.IntegrationPhaseDeploying
+	environment.Platform.ResyncStatusFullConfig()
+
+	_, err = traitCatalog.apply(&environment)
+	require.NoError(t, err)
+	container := environment.GetIntegrationContainer()
+	assert.Len(t, container.Ports, 1)
+	assert.Equal(t, int32(8081), container.Ports[0].ContainerPort)
+	assert.Equal(t, "", container.Ports[0].Name)
+}
