@@ -21,6 +21,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
@@ -33,24 +34,27 @@ func TestDependenciesTraitApplicability(t *testing.T) {
 	}
 
 	trait := newDependenciesTrait()
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.False(t, enabled)
 
 	e.Integration.Status.Phase = v1.IntegrationPhaseNone
-	enabled, err = trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err = trait.Configure(e)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.False(t, enabled)
 
 	e.Integration.Status.Phase = v1.IntegrationPhaseInitialization
-	enabled, err = trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err = trait.Configure(e)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, enabled)
 }
 
 func TestIntegrationDefaultDeps(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	e := &Environment{
 		Catalog:      NewEnvironmentTestCatalog(),
@@ -74,12 +78,13 @@ func TestIntegrationDefaultDeps(t *testing.T) {
 	}
 
 	trait := newDependenciesTrait()
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, enabled)
 
 	err = trait.Apply(e)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.ElementsMatch(
 		t,
 		[]string{
@@ -94,7 +99,7 @@ func TestIntegrationDefaultDeps(t *testing.T) {
 
 func TestIntegrationCustomDeps(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	e := &Environment{
 		Catalog:      NewEnvironmentTestCatalog(),
@@ -122,12 +127,13 @@ func TestIntegrationCustomDeps(t *testing.T) {
 	}
 
 	trait := newDependenciesTrait()
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, enabled)
 
 	err = trait.Apply(e)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.ElementsMatch(t,
 		[]string{
 			"camel:direct",
@@ -143,7 +149,7 @@ func TestIntegrationCustomDeps(t *testing.T) {
 
 func TestIntegrationAutoGeneratedDeps(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	e := &Environment{
 		Catalog:      NewEnvironmentTestCatalog(),
@@ -176,8 +182,9 @@ func TestIntegrationAutoGeneratedDeps(t *testing.T) {
 	}
 
 	for _, trait := range []Trait{NewInitTrait(), newDependenciesTrait()} {
-		enabled, err := trait.Configure(e)
-		assert.Nil(t, err)
+		enabled, condition, err := trait.Configure(e)
+		require.NoError(t, err)
+		assert.Nil(t, condition)
 		assert.True(t, enabled)
 		assert.Nil(t, trait.Apply(e))
 	}
@@ -206,7 +213,7 @@ func TestIntegrationAutoGeneratedDeps(t *testing.T) {
 // account when dependencies are computed.
 func TestIntegrationCustomLoader(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	e := &Environment{
 		Catalog:      NewEnvironmentTestCatalog(),
@@ -231,12 +238,13 @@ func TestIntegrationCustomLoader(t *testing.T) {
 	}
 
 	trait := newDependenciesTrait()
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, enabled)
 
 	err = trait.Apply(e)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.ElementsMatch(t,
 		[]string{
 			"camel:direct",
@@ -250,7 +258,7 @@ func TestIntegrationCustomLoader(t *testing.T) {
 
 func TestRestDeps(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	e := &Environment{
 		Catalog:      NewEnvironmentTestCatalog(),
@@ -274,12 +282,13 @@ func TestRestDeps(t *testing.T) {
 	}
 
 	trait := newDependenciesTrait()
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, enabled)
 
 	err = trait.Apply(e)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Subset(
 		t,
 		e.Integration.Status.Dependencies,
@@ -292,7 +301,7 @@ func TestRestDeps(t *testing.T) {
 
 func TestRestDepsQuarkus(t *testing.T) {
 	catalog, err := camel.QuarkusCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	e := &Environment{
 		Catalog:      NewEnvironmentTestCatalog(),
@@ -316,12 +325,13 @@ func TestRestDepsQuarkus(t *testing.T) {
 	}
 
 	trait := newDependenciesTrait()
-	enabled, err := trait.Configure(e)
-	assert.Nil(t, err)
+	enabled, condition, err := trait.Configure(e)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 	assert.True(t, enabled)
 
 	err = trait.Apply(e)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Subset(
 		t,
 		e.Integration.Status.Dependencies,
