@@ -22,27 +22,39 @@ import (
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
+	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/utils/pointer"
 )
 
 func TestConfigureGCTraitDoesSucceed(t *testing.T) {
 	gcTrait, environment := createNominalGCTest()
-	configured, err := gcTrait.Configure(environment)
+	configured, condition, err := gcTrait.Configure(environment)
 
 	assert.True(t, configured)
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
+
 }
 
 func TestConfigureDisabledGCTraitDoesNotSucceed(t *testing.T) {
 	gcTrait, environment := createNominalGCTest()
 	gcTrait.Enabled = pointer.Bool(false)
 
-	configured, err := gcTrait.Configure(environment)
-
+	expectedCondition := NewIntegrationCondition(
+		"GC",
+		v1.IntegrationConditionTraitInfo,
+		corev1.ConditionTrue,
+		"TraitConfiguration",
+		"explicitly disabled by the user",
+	)
+	configured, condition, err := gcTrait.Configure(environment)
 	assert.False(t, configured)
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.NotNil(t, condition)
+	assert.Equal(t, expectedCondition, condition)
 }
 
 func TestApplyGarbageCollectorTraitFirstGenerationDoesSucceed(t *testing.T) {
@@ -50,7 +62,7 @@ func TestApplyGarbageCollectorTraitFirstGenerationDoesSucceed(t *testing.T) {
 
 	err := gcTrait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, environment.PostProcessors, 1)
 	assert.Len(t, environment.PostActions, 0)
 }
@@ -61,7 +73,7 @@ func TestApplyGarbageCollectorTraitNextGenerationDoesSucceed(t *testing.T) {
 
 	err := gcTrait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, environment.PostProcessors, 1)
 	assert.Len(t, environment.PostActions, 1)
 }
@@ -72,7 +84,7 @@ func TestApplyGCTraitDuringInitializationPhaseSkipPostActions(t *testing.T) {
 
 	err := gcTrait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, environment.PostProcessors, 1)
 	assert.Len(t, environment.PostActions, 0)
 }
