@@ -18,6 +18,7 @@ limitations under the License.
 package trait
 
 import (
+	"fmt"
 	"sort"
 
 	corev1 "k8s.io/api/core/v1"
@@ -51,17 +52,16 @@ func newHealthTrait() Trait {
 	}
 }
 
-func (t *healthTrait) Configure(e *Environment) (bool, error) {
+func (t *healthTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 	if e.Integration == nil ||
 		!e.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !e.IntegrationInRunningPhases() {
-		return false, nil
+		return false, nil, nil
 	}
-
 	if !pointer.BoolDeref(t.Enabled, false) {
-		return false, nil
+		return false, nil, nil
 	}
 
-	return true, nil
+	return true, nil, nil
 }
 
 func (t *healthTrait) Apply(e *Environment) error {
@@ -81,6 +81,9 @@ func (t *healthTrait) Apply(e *Environment) error {
 	}
 
 	container := e.GetIntegrationContainer()
+	if container == nil {
+		return fmt.Errorf("unable to find integration container: %s", e.Integration.Name)
+	}
 	var port *intstr.IntOrString
 	// Use the default named HTTP container port if it exists.
 	// For Knative, the Serving webhook is responsible for setting the user-land port,
@@ -93,6 +96,29 @@ func (t *healthTrait) Apply(e *Environment) error {
 		port = &p
 	}
 
+	if e.CamelCatalog.Runtime.Capabilities["health"].Metadata != nil {
+		t.setCatalogConfiguration(container, port, e.CamelCatalog.Runtime.Capabilities["health"].Metadata)
+	} else {
+		t.setDefaultConfiguration(container, port)
+	}
+
+	return nil
+}
+
+func (t *healthTrait) setCatalogConfiguration(container *corev1.Container, port *intstr.IntOrString, metadata map[string]string) {
+	if pointer.BoolDeref(t.LivenessProbeEnabled, false) {
+		container.LivenessProbe = t.newLivenessProbe(port, metadata["defaultLivenessProbePath"])
+	}
+	if pointer.BoolDeref(t.ReadinessProbeEnabled, true) {
+		container.ReadinessProbe = t.newReadinessProbe(port, metadata["defaultReadinessProbePath"])
+	}
+	if pointer.BoolDeref(t.StartupProbeEnabled, false) {
+		container.StartupProbe = t.newStartupProbe(port, metadata["defaultStartupProbePath"])
+	}
+}
+
+// Deprecated: to be removed in future release in favor of func setCatalogConfiguration().
+func (t *healthTrait) setDefaultConfiguration(container *corev1.Container, port *intstr.IntOrString) {
 	if pointer.BoolDeref(t.LivenessProbeEnabled, false) {
 		container.LivenessProbe = t.newLivenessProbe(port, defaultLivenessProbePath)
 	}
@@ -102,8 +128,6 @@ func (t *healthTrait) Apply(e *Environment) error {
 	if pointer.BoolDeref(t.StartupProbeEnabled, false) {
 		container.StartupProbe = t.newStartupProbe(port, defaultStartupProbePath)
 	}
-
-	return nil
 }
 
 func (t *healthTrait) newLivenessProbe(port *intstr.IntOrString, path string) *corev1.Probe {
