@@ -44,26 +44,17 @@ func newJolokiaTrait() Trait {
 	}
 }
 
-func (t *jolokiaTrait) Configure(e *Environment) (bool, error) {
+func (t *jolokiaTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, false) {
-		return false, nil
+		return false, nil, nil
 	}
 
-	return e.IntegrationInPhase(v1.IntegrationPhaseInitialization) || e.IntegrationInRunningPhases(), nil
+	return e.IntegrationInPhase(v1.IntegrationPhaseInitialization) || e.IntegrationInRunningPhases(), nil, nil
 }
 
 func (t *jolokiaTrait) Apply(e *Environment) error {
 	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
-		// Add the Camel management and Jolokia agent dependencies
-		// Also add the Camel JAXB dependency, that's required by Hawtio
-
-		if e.CamelCatalog.Runtime.Provider == v1.RuntimeProviderQuarkus {
-			util.StringSliceUniqueAdd(&e.Integration.Status.Dependencies, "camel-quarkus:management")
-			util.StringSliceUniqueAdd(&e.Integration.Status.Dependencies, "camel:jaxb")
-		}
-
-		util.StringSliceUniqueAdd(&e.Integration.Status.Dependencies, "mvn:org.jolokia:jolokia-jvm")
-
+		util.StringSliceUniqueAdd(&e.Integration.Status.Capabilities, v1.CapabilityJolokia)
 		return nil
 	}
 
@@ -123,7 +114,7 @@ func (t *jolokiaTrait) Apply(e *Environment) error {
 
 	jolokiaFilepath := ""
 	for _, ar := range e.IntegrationKit.Status.Artifacts {
-		if strings.HasPrefix(ar.ID, "org.jolokia.jolokia-jvm") {
+		if strings.HasPrefix(ar.ID, "org.jolokia.jolokia-agent-jvm") || strings.HasPrefix(ar.ID, "org.jolokia.jolokia-jvm") {
 			jolokiaFilepath = ar.Target
 			break
 		}
