@@ -55,23 +55,30 @@ func newJvmTrait() Trait {
 	}
 }
 
-func (t *jvmTrait) Configure(e *Environment) (bool, error) {
+func (t *jvmTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 	if !pointer.BoolDeref(t.Enabled, true) {
-		return false, nil
+		return false, NewIntegrationConditionUserDisabled("JVM"), nil
 	}
-
 	if !e.IntegrationKitInPhase(v1.IntegrationKitPhaseReady) || !e.IntegrationInRunningPhases() {
-		return false, nil
+		return false, nil, nil
 	}
 
-	if trait := e.Catalog.GetTrait(quarkusTraitID); trait != nil {
-		// The JVM trait must be disabled in case the current IntegrationKit corresponds to a native build
-		if quarkus, ok := trait.(*quarkusTrait); ok && pointer.BoolDeref(quarkus.Enabled, true) && quarkus.isNativeIntegration(e) {
-			return false, nil
+	// The JVM trait must be disabled in case the current IntegrationKit corresponds to a native build
+	if qt := e.Catalog.GetTrait(quarkusTraitID); qt != nil {
+		if quarkus, ok := qt.(*quarkusTrait); ok && quarkus.isNativeIntegration(e) {
+			return false, newIntegrationConditionPlatformDisabledWithMessage("JVM", "quarkus native build"), nil
 		}
 	}
 
-	return true, nil
+	if e.IntegrationKit != nil && e.IntegrationKit.IsExternal() {
+		if pointer.BoolDeref(t.Enabled, false) {
+			return true, NewIntegrationConditionUserEnabledWithMessage("JVM", "integration kit was not created via Camel K operator"), nil
+		} else {
+			return false, newIntegrationConditionPlatformDisabledWithMessage("JVM", "integration kit was not created via Camel K operator"), nil
+		}
+	}
+
+	return true, nil, nil
 }
 
 // nolint: maintidx // TODO: refactor the code
@@ -83,7 +90,7 @@ func (t *jvmTrait) Apply(e *Environment) error {
 		ns := e.Integration.GetIntegrationKitNamespace(e.Platform)
 		k := v1.NewIntegrationKit(ns, name)
 		if err := t.Client.Get(e.Ctx, ctrl.ObjectKeyFromObject(k), k); err != nil {
-			return fmt.Errorf("unable to find integration kit %s/%s, %s: %w", ns, name, err, err)
+			return fmt.Errorf("unable to find integration kit %s/%s: %w", ns, name, err)
 		}
 		kit = k
 	}
@@ -108,7 +115,7 @@ func (t *jvmTrait) Apply(e *Environment) error {
 		classpath.Add(artifact.Target)
 	}
 
-	if kit.Labels[v1.IntegrationKitTypeLabel] == v1.IntegrationKitTypeExternal {
+	if kit.IsExternal() {
 		// In case of an external created kit, we do not have any information about
 		// the classpath, so we assume the all jars in /deployments/dependencies/ have
 		// to be taken into account.
@@ -124,7 +131,7 @@ func (t *jvmTrait) Apply(e *Environment) error {
 
 	container := e.GetIntegrationContainer()
 	if container == nil {
-		return fmt.Errorf("unable to find integration container")
+		return fmt.Errorf("unable to find integration container: %s", e.Integration.Name)
 	}
 
 	// Build the container command
@@ -237,7 +244,7 @@ func (t *jvmTrait) Apply(e *Environment) error {
 
 	args = append(args, e.CamelCatalog.Runtime.ApplicationClass)
 
-	if pointer.BoolDeref(t.PrintCommand, true) {
+	if pointer.BoolDeref(t.PrintCommand, false) {
 		args = append([]string{"exec", "java"}, args...)
 		container.Command = []string{"/bin/sh", "-c"}
 		cmd := strings.Join(args, " ")
@@ -251,8 +258,3 @@ func (t *jvmTrait) Apply(e *Environment) error {
 
 	return nil
 }
-
-// IsPlatformTrait overrides base class method.
-func (t *jvmTrait) IsPlatformTrait() bool {
-	return true
-}
