@@ -25,6 +25,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -49,36 +50,83 @@ var (
 func TestConfigureJvmTraitInRightPhasesDoesSucceed(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
 	assert.True(t, configured)
+	assert.Nil(t, condition)
 }
 
 func TestConfigureJvmTraitInWrongIntegrationPhaseDoesNotSucceed(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
 	environment.Integration.Status.Phase = v1.IntegrationPhaseError
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
 	assert.True(t, configured)
+	assert.Nil(t, condition)
 }
 
 func TestConfigureJvmTraitInWrongIntegrationKitPhaseDoesNotSucceed(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
 	environment.IntegrationKit.Status.Phase = v1.IntegrationKitPhaseWaitingForPlatform
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
 	assert.False(t, configured)
+	assert.Nil(t, condition)
 }
 
-func TestConfigureJvmDisabledTraitDoesNotSucceed(t *testing.T) {
+func TestConfigureJvmTraitInWrongJvmDisabled(t *testing.T) {
 	trait, environment := createNominalJvmTest(v1.IntegrationKitTypePlatform)
 	trait.Enabled = pointer.Bool(false)
 
-	configured, err := trait.Configure(environment)
-	assert.Nil(t, err)
+	expectedCondition := NewIntegrationCondition(
+		"JVM",
+		v1.IntegrationConditionTraitInfo,
+		corev1.ConditionTrue,
+		"TraitConfiguration",
+		"explicitly disabled by the user",
+	)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
 	assert.False(t, configured)
+	assert.NotNil(t, condition)
+	assert.Equal(t, expectedCondition, condition)
+}
+
+func TestConfigureJvmTraitInWrongIntegrationKitPhaseExternal(t *testing.T) {
+	trait, environment := createNominalJvmTest(v1.IntegrationKitTypeExternal)
+
+	expectedCondition := NewIntegrationCondition(
+		"JVM",
+		v1.IntegrationConditionTraitInfo,
+		corev1.ConditionTrue,
+		"TraitConfiguration",
+		"explicitly disabled by the platform: integration kit was not created via Camel K operator",
+	)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.False(t, configured)
+	assert.NotNil(t, condition)
+	assert.Equal(t, expectedCondition, condition)
+}
+
+func TestConfigureJvmTraitInRightIntegrationKitPhaseExternalAndJvmEnabled(t *testing.T) {
+	trait, environment := createNominalJvmTest(v1.IntegrationKitTypeExternal)
+	trait.Enabled = pointer.Bool(true)
+
+	expectedCondition := NewIntegrationCondition(
+		"JVM",
+		v1.IntegrationConditionTraitInfo,
+		corev1.ConditionTrue,
+		"TraitConfiguration",
+		"explicitly enabled by the user: integration kit was not created via Camel K operator",
+	)
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.True(t, configured)
+	assert.NotNil(t, condition)
+	assert.Equal(t, expectedCondition, condition)
 }
 
 func TestApplyJvmTraitWithDeploymentResource(t *testing.T) {
@@ -107,7 +155,7 @@ func TestApplyJvmTraitWithDeploymentResource(t *testing.T) {
 
 	err := trait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	s := sets.NewSet()
 	s.Add("./resources", crMountPath, rdMountPath, "/mount/path")
@@ -141,7 +189,7 @@ func TestApplyJvmTraitWithKNativeResource(t *testing.T) {
 
 	err := trait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	st := sets.NewSet()
 	st.Add("./resources", crMountPath, rdMountPath, "/mount/path")
@@ -183,7 +231,7 @@ func TestApplyJvmTraitWithDebugEnabled(t *testing.T) {
 
 	err := trait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	assert.Contains(t, d.Spec.Template.Spec.Containers[0].Args,
 		"-agentlib:jdwp=transport=dt_socket,server=y,suspend=y,address=*:5005",
@@ -210,7 +258,7 @@ func TestApplyJvmTraitWithExternalKitType(t *testing.T) {
 	environment.Resources.Add(&d)
 
 	err := trait.Apply(environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	container := environment.GetIntegrationContainer()
 
@@ -251,7 +299,7 @@ func TestApplyJvmTraitWithClasspath(t *testing.T) {
 	environment.Resources.Add(&d)
 	err := trait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, []string{
 		"-cp",
 		fmt.Sprintf("./resources:%s:%s:/mount/path:%s:%s", crMountPath, rdMountPath,
@@ -262,11 +310,8 @@ func TestApplyJvmTraitWithClasspath(t *testing.T) {
 
 func createNominalJvmTest(kitType string) (*jvmTrait, *Environment) {
 	catalog, _ := camel.DefaultCatalog()
-
 	client, _ := test.NewFakeClient()
-
 	trait, _ := newJvmTrait().(*jvmTrait)
-	trait.Enabled = pointer.Bool(true)
 	trait.PrintCommand = pointer.Bool(false)
 	trait.Client = client
 
