@@ -20,6 +20,7 @@ package trait
 import (
 	"errors"
 	"fmt"
+	"path/filepath"
 	"sort"
 	"strconv"
 	"strings"
@@ -30,20 +31,23 @@ import (
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
-
-	kameletutils "github.com/apache/camel-k/v2/pkg/kamelet"
 	"github.com/apache/camel-k/v2/pkg/kamelet/repository"
 	"github.com/apache/camel-k/v2/pkg/platform"
 	"github.com/apache/camel-k/v2/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/digest"
 	"github.com/apache/camel-k/v2/pkg/util/dsl"
 	"github.com/apache/camel-k/v2/pkg/util/kamelets"
 )
 
-type kameletsTrait struct {
-	BaseTrait
-	traitv1.KameletsTrait `property:",squash"`
-}
+const (
+	kameletsTraitID             = "kamelets"
+	contentKey                  = "content"
+	KameletLocationProperty     = "camel.component.kamelet.location"
+	kameletLabel                = "camel.apache.org/kamelet"
+	kameletConfigurationLabel   = "camel.apache.org/kamelet.configuration"
+	kameletMountPointAnnotation = "camel.apache.org/kamelet.mount-point"
+)
 
 type configurationKey struct {
 	kamelet         string
@@ -57,12 +61,10 @@ func newConfigurationKey(kamelet, configurationID string) configurationKey {
 	}
 }
 
-const (
-	contentKey = "content"
-
-	kameletLabel              = "camel.apache.org/kamelet"
-	kameletConfigurationLabel = "camel.apache.org/kamelet.configuration"
-)
+type kameletsTrait struct {
+	BaseTrait
+	traitv1.KameletsTrait `property:",squash"`
+}
 
 func newKameletsTrait() Trait {
 	return &kameletsTrait{
@@ -70,33 +72,34 @@ func newKameletsTrait() Trait {
 	}
 }
 
-// IsPlatformTrait overrides base class method.
-func (t *kameletsTrait) IsPlatformTrait() bool {
-	return true
-}
-
-func (t *kameletsTrait) Configure(e *Environment) (bool, error) {
-	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
-		return false, nil
+func (t *kameletsTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	if e.Integration == nil {
+		return false, nil, nil
+	}
+	if !pointer.BoolDeref(t.Enabled, true) {
+		return false, NewIntegrationConditionUserDisabled("Kamelets"), nil
 	}
-
 	if !e.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !e.IntegrationInRunningPhases() {
-		return false, nil
+		return false, nil, nil
 	}
 
 	if pointer.BoolDeref(t.Auto, true) {
 		kamelets, err := kamelets.ExtractKameletFromSources(e.Ctx, e.Client, e.CamelCatalog, e.Resources, e.Integration)
 		if err != nil {
-			return false, err
+			return false, nil, err
 		}
 
 		if len(kamelets) > 0 {
 			sort.Strings(kamelets)
 			t.List = strings.Join(kamelets, ",")
 		}
+
+		if t.MountPoint == "" {
+			t.MountPoint = filepath.Join(camel.BasePath, "kamelets")
+		}
 	}
 
-	return len(t.getKameletKeys()) > 0, nil
+	return len(t.getKameletKeys()) > 0, nil, nil
 }
 
 func (t *kameletsTrait) Apply(e *Environment) error {
@@ -105,12 +108,6 @@ func (t *kameletsTrait) Apply(e *Environment) error {
 			return err
 		}
 	}
-	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
-		return t.addConfigurationSecrets(e)
-	} else if e.IntegrationInRunningPhases() {
-		return t.configureApplicationProperties(e)
-	}
-
 	return nil
 }
 
@@ -134,12 +131,7 @@ func (t *kameletsTrait) collectKamelets(e *Environment) (map[string]*v1.Kamelet,
 			missingKamelets = append(missingKamelets, key)
 		} else {
 			availableKamelets = append(availableKamelets, key)
-
-			// Initialize remote kamelets
-			kamelets[key], err = kameletutils.Initialize(kamelet)
-			if err != nil {
-				return nil, err
-			}
+			kamelets[key] = kamelet
 		}
 	}
 
@@ -147,7 +139,7 @@ func (t *kameletsTrait) collectKamelets(e *Environment) (map[string]*v1.Kamelet,
 	sort.Strings(missingKamelets)
 
 	if len(missingKamelets) > 0 {
-		message := fmt.Sprintf("kamelets [%s] found, [%s] not found in repositories: %s",
+		message := fmt.Sprintf("kamelets [%s] found, kamelets [%s] not found in %s repositories",
 			strings.Join(availableKamelets, ","),
 			strings.Join(missingKamelets, ","),
 			repo.String())
@@ -166,7 +158,7 @@ func (t *kameletsTrait) collectKamelets(e *Environment) (map[string]*v1.Kamelet,
 		v1.IntegrationConditionKameletsAvailable,
 		corev1.ConditionTrue,
 		v1.IntegrationConditionKameletsAvailableReason,
-		fmt.Sprintf("kamelets [%s] found in repositories: %s", strings.Join(availableKamelets, ","), repo.String()),
+		fmt.Sprintf("kamelets [%s] found in %s repositories", strings.Join(availableKamelets, ","), repo.String()),
 	)
 
 	return kamelets, nil
@@ -178,59 +170,45 @@ func (t *kameletsTrait) addKamelets(e *Environment) error {
 		if err != nil {
 			return err
 		}
-
+		kb := newKameletBundle()
 		for _, key := range t.getKameletKeys() {
 			kamelet := kamelets[key]
-
-			if kamelet.Status.Phase != v1.KameletPhaseReady {
-				return fmt.Errorf("kamelet %q is not %s: %s", key, v1.KameletPhaseReady, kamelet.Status.Phase)
-			}
-
 			if err := t.addKameletAsSource(e, kamelet); err != nil {
 				return err
 			}
-
 			// Adding dependencies from Kamelets
 			util.StringSliceUniqueConcat(&e.Integration.Status.Dependencies, kamelet.Spec.Dependencies)
+			// Add to Kamelet bundle configmap
+			kb.add(kamelet)
 		}
+		bundleConfigmaps, err := kb.toConfigmaps(e.Integration.Name, e.Integration.Namespace)
+		if err != nil {
+			return err
+		}
+		// set kamelets runtime location
+		if e.ApplicationProperties == nil {
+			e.ApplicationProperties = map[string]string{}
+		}
+		for _, cm := range bundleConfigmaps {
+			kameletMountPoint := fmt.Sprintf("%s/%s", t.MountPoint, cm.Name)
+			cm.Annotations[kameletMountPointAnnotation] = kameletMountPoint
+			e.Resources.Add(cm)
+			if e.ApplicationProperties[KameletLocationProperty] == "" {
+				e.ApplicationProperties[KameletLocationProperty] = fmt.Sprintf("file:%s", kameletMountPoint)
+			} else {
+				e.ApplicationProperties[KameletLocationProperty] += fmt.Sprintf(",file:%s", kameletMountPoint)
+			}
+		}
+		e.ApplicationProperties[KameletLocationProperty] += ",classpath:/kamelets"
 		// resort dependencies
 		sort.Strings(e.Integration.Status.Dependencies)
 	}
 	return nil
 }
 
-func (t *kameletsTrait) configureApplicationProperties(e *Environment) error {
-	if len(t.getKameletKeys()) > 0 {
-		kamelets, err := t.collectKamelets(e)
-		if err != nil {
-			return err
-		}
-
-		for _, key := range t.getKameletKeys() {
-			kamelet := kamelets[key]
-			// Configuring defaults from Kamelet
-			for _, prop := range kamelet.Status.Properties {
-				if prop.Default != "" {
-					// Check whether user specified a value
-					userDefined := false
-					propName := fmt.Sprintf("camel.kamelet.%s.%s", kamelet.Name, prop.Name)
-					propPrefix := propName + "="
-					for _, userProp := range e.Integration.Spec.Configuration {
-						if strings.HasPrefix(userProp.Value, propPrefix) {
-							userDefined = true
-							break
-						}
-					}
-					if !userDefined {
-						e.ApplicationProperties[propName] = prop.Default
-					}
-				}
-			}
-		}
-	}
-	return nil
-}
-
+// This func will add a Kamelet as a generated Integration source. The source included here is going to be used in order to parse the Kamelet
+// for any component or capability (ie, rest) which is included in the Kamelet spec itself. However, the generated source is marked as coming `FromKamelet`.
+// When mounting the sources, these generated sources won't be mounted as sources but as Kamelet instead.
 func (t *kameletsTrait) addKameletAsSource(e *Environment, kamelet *v1.Kamelet) error {
 	sources := make([]v1.SourceSpec, 0)
 
@@ -246,7 +224,8 @@ func (t *kameletsTrait) addKameletAsSource(e *Environment, kamelet *v1.Kamelet)
 				Name:    fmt.Sprintf("%s.yaml", kamelet.Name),
 				Content: string(flowData),
 			},
-			Language: v1.LanguageYaml,
+			Language:    v1.LanguageYaml,
+			FromKamelet: true,
 		}
 		flowSource, err = integrationSourceFromKameletSource(e, kamelet, flowSource, fmt.Sprintf("%s-kamelet-%s-template", e.Integration.Name, kamelet.Name))
 		if err != nil {
@@ -279,7 +258,9 @@ func (t *kameletsTrait) addKameletAsSource(e *Environment, kamelet *v1.Kamelet)
 	return nil
 }
 
-func (t *kameletsTrait) addConfigurationSecrets(e *Environment) error {
+// Deprecated: use explicit secret configuration instead.
+func (t *kameletsTrait) listConfigurationSecrets(e *Environment) ([]string, error) {
+	listConfigurationSecrets := make([]string, 0)
 	for _, k := range t.getConfigurationKeys() {
 		options := metav1.ListOptions{
 			LabelSelector: fmt.Sprintf("%s=%s", kameletLabel, k.kamelet),
@@ -289,21 +270,16 @@ func (t *kameletsTrait) addConfigurationSecrets(e *Environment) error {
 		}
 		secrets, err := t.Client.CoreV1().Secrets(e.Integration.Namespace).List(e.Ctx, options)
 		if err != nil {
-			return err
+			return nil, err
 		}
-
 		for _, item := range secrets.Items {
 			if item.Labels != nil && item.Labels[kameletConfigurationLabel] != k.configurationID {
 				continue
 			}
-
-			e.Integration.Status.AddConfigurationsIfMissing(v1.ConfigurationSpec{
-				Type:  "secret",
-				Value: item.Name,
-			})
+			listConfigurationSecrets = append(listConfigurationSecrets, item.Name)
 		}
 	}
-	return nil
+	return listConfigurationSecrets, nil
 }
 
 func (t *kameletsTrait) getKameletKeys() []string {
@@ -368,33 +344,7 @@ func integrationSourceFromKameletSource(e *Environment, kamelet *v1.Kamelet, sou
 	if err != nil {
 		return v1.SourceSpec{}, err
 	}
-
-	cm := corev1.ConfigMap{
-		TypeMeta: metav1.TypeMeta{
-			Kind:       "ConfigMap",
-			APIVersion: "v1",
-		},
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      name,
-			Namespace: e.Integration.Namespace,
-			Labels: map[string]string{
-				"camel.apache.org/integration": e.Integration.Name,
-				"camel.apache.org/kamelet":     kamelet.Name,
-			},
-			Annotations: map[string]string{
-				"camel.apache.org/source.language":    string(source.Language),
-				"camel.apache.org/source.name":        name,
-				"camel.apache.org/source.compression": strconv.FormatBool(source.Compression),
-				"camel.apache.org/source.generated":   "true",
-				"camel.apache.org/source.type":        string(source.Type),
-				"camel.apache.org/source.digest":      hash,
-			},
-		},
-		Data: map[string]string{
-			contentKey: source.Content,
-		},
-	}
-
+	cm := initializeConfigmapKameletSource(source, hash, name, e.Integration.Namespace, e.Integration.Name, kamelet.Name)
 	e.Resources.Add(&cm)
 
 	target := source.DeepCopy()
@@ -403,3 +353,31 @@ func integrationSourceFromKameletSource(e *Environment, kamelet *v1.Kamelet, sou
 	target.ContentKey = contentKey
 	return *target, nil
 }
+
+func initializeConfigmapKameletSource(source v1.SourceSpec, hash, name, namespace, itName, kamName string) corev1.ConfigMap {
+	return corev1.ConfigMap{
+		TypeMeta: metav1.TypeMeta{
+			Kind:       "ConfigMap",
+			APIVersion: "v1",
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      name,
+			Namespace: namespace,
+			Labels: map[string]string{
+				"camel.apache.org/integration": itName,
+				"camel.apache.org/kamelet":     kamName,
+			},
+			Annotations: map[string]string{
+				sourceLanguageAnnotation:            string(source.Language),
+				sourceNameAnnotation:                name,
+				sourceCompressionAnnotation:         strconv.FormatBool(source.Compression),
+				"camel.apache.org/source.generated": "true",
+				"camel.apache.org/source.type":      string(source.Type),
+				"camel.apache.org/source.digest":    hash,
+			},
+		},
+		Data: map[string]string{
+			contentKey: source.Content,
+		},
+	}
+}
