@@ -39,7 +39,7 @@ import (
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/metadata"
 	"github.com/apache/camel-k/v2/pkg/util"
-	"github.com/apache/camel-k/v2/pkg/util/envvar"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
 	knativeutil "github.com/apache/camel-k/v2/pkg/util/knative"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 )
@@ -66,106 +66,68 @@ func (t *knativeTrait) IsAllowedInProfile(profile v1.TraitProfile) bool {
 	return profile.Equal(v1.TraitProfileKnative)
 }
 
-func (t *knativeTrait) Configure(e *Environment) (bool, error) {
-	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
-		return false, nil
+func (t *knativeTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	if e.Integration == nil {
+		return false, nil, nil
+	}
+	if !pointer.BoolDeref(t.Enabled, true) {
+		return false, NewIntegrationConditionUserDisabled("Knative"), nil
 	}
-
 	if !e.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !e.IntegrationInRunningPhases() {
-		return false, nil
+		return false, nil, nil
 	}
-
 	if pointer.BoolDeref(t.Auto, true) {
+		sources, err := kubernetes.ResolveIntegrationSources(e.Ctx, e.Client, e.Integration, e.Resources)
+		if err != nil {
+			return false, nil, err
+		}
 		if len(t.ChannelSources) == 0 {
-			items := make([]string, 0)
-			sources, err := kubernetes.ResolveIntegrationSources(e.Ctx, e.Client, e.Integration, e.Resources)
+			items, err := filterMetaItems(e.CamelCatalog, sources, knativeapi.CamelServiceTypeChannel, "from")
 			if err != nil {
-				return false, err
+				return false, nil, err
 			}
-			if err := metadata.Each(e.CamelCatalog, sources, func(_ int, meta metadata.IntegrationMetadata) bool {
-				items = append(items, knativeutil.FilterURIs(meta.FromURIs, knativeapi.CamelServiceTypeChannel)...)
-				return true
-			}); err != nil {
-				return false, err
-			}
-
 			t.ChannelSources = items
 		}
 		if len(t.ChannelSinks) == 0 {
-			items := make([]string, 0)
-			sources, err := kubernetes.ResolveIntegrationSources(e.Ctx, e.Client, e.Integration, e.Resources)
+			items, err := filterMetaItems(e.CamelCatalog, sources, knativeapi.CamelServiceTypeChannel, "to")
 			if err != nil {
-				return false, err
+				return false, nil, err
 			}
-			if err := metadata.Each(e.CamelCatalog, sources, func(_ int, meta metadata.IntegrationMetadata) bool {
-				items = append(items, knativeutil.FilterURIs(meta.ToURIs, knativeapi.CamelServiceTypeChannel)...)
-				return true
-			}); err != nil {
-				return false, err
-			}
-
 			t.ChannelSinks = items
 		}
 		if len(t.EndpointSources) == 0 {
-			items := make([]string, 0)
-			sources, err := kubernetes.ResolveIntegrationSources(e.Ctx, e.Client, e.Integration, e.Resources)
+			items, err := filterMetaItems(e.CamelCatalog, sources, knativeapi.CamelServiceTypeEndpoint, "from")
 			if err != nil {
-				return false, err
+				return false, nil, err
 			}
-			if err := metadata.Each(e.CamelCatalog, sources, func(_ int, meta metadata.IntegrationMetadata) bool {
-				items = append(items, knativeutil.FilterURIs(meta.FromURIs, knativeapi.CamelServiceTypeEndpoint)...)
-				return true
-			}); err != nil {
-				return false, err
-			}
-
 			t.EndpointSources = items
 		}
 		if len(t.EndpointSinks) == 0 {
-			items := make([]string, 0)
-			sources, err := kubernetes.ResolveIntegrationSources(e.Ctx, e.Client, e.Integration, e.Resources)
+			items, err := filterMetaItems(e.CamelCatalog, sources, knativeapi.CamelServiceTypeEndpoint, "to")
 			if err != nil {
-				return false, err
+				return false, nil, err
 			}
-			if err := metadata.Each(e.CamelCatalog, sources, func(_ int, meta metadata.IntegrationMetadata) bool {
-				items = append(items, knativeutil.FilterURIs(meta.ToURIs, knativeapi.CamelServiceTypeEndpoint)...)
-				return true
-			}); err != nil {
-				return false, err
-			}
-
 			t.EndpointSinks = items
 		}
 		if len(t.EventSources) == 0 {
-			items := make([]string, 0)
-			sources, err := kubernetes.ResolveIntegrationSources(e.Ctx, e.Client, e.Integration, e.Resources)
+			items, err := filterMetaItems(e.CamelCatalog, sources, knativeapi.CamelServiceTypeEvent, "from")
 			if err != nil {
-				return false, err
+				return false, nil, err
 			}
-			if err := metadata.Each(e.CamelCatalog, sources, func(_ int, meta metadata.IntegrationMetadata) bool {
-				items = append(items, knativeutil.FilterURIs(meta.FromURIs, knativeapi.CamelServiceTypeEvent)...)
-				return true
-			}); err != nil {
-				return false, err
-			}
-
 			t.EventSources = items
 		}
 		if len(t.EventSinks) == 0 {
-			items := make([]string, 0)
-			sources, err := kubernetes.ResolveIntegrationSources(e.Ctx, e.Client, e.Integration, e.Resources)
+			items, err := filterMetaItems(e.CamelCatalog, sources, knativeapi.CamelServiceTypeEvent, "to")
 			if err != nil {
-				return false, err
+				return false, nil, err
 			}
-			if err := metadata.Each(e.CamelCatalog, sources, func(_ int, meta metadata.IntegrationMetadata) bool {
-				items = append(items, knativeutil.FilterURIs(meta.ToURIs, knativeapi.CamelServiceTypeEvent)...)
-				return true
-			}); err != nil {
-				return false, err
-			}
-
 			t.EventSinks = items
 		}
+		hasKnativeEndpoint := len(t.ChannelSources) > 0 || len(t.ChannelSinks) > 0 || len(t.EndpointSources) > 0 || len(t.EndpointSinks) > 0 || len(t.EventSources) > 0 || len(t.EventSinks) > 0
+		t.Enabled = &hasKnativeEndpoint
+		if !hasKnativeEndpoint {
+			return false, nil, nil
+		}
 		if t.FilterSourceChannels == nil {
 			// Filtering is no longer used by default
 			t.FilterSourceChannels = pointer.Bool(false)
@@ -176,13 +138,31 @@ func (t *knativeTrait) Configure(e *Environment) (bool, error) {
 		}
 	}
 
-	return true, nil
+	return true, nil, nil
+}
+
+func filterMetaItems(catalog *camel.RuntimeCatalog, sources []v1.SourceSpec, cst knativeapi.CamelServiceType, uriType string) ([]string, error) {
+	items := make([]string, 0)
+	if err := metadata.Each(catalog, sources, func(_ int, meta metadata.IntegrationMetadata) bool {
+		var uris []string
+		if uriType == "from" {
+			uris = meta.FromURIs
+		} else if uriType == "to" {
+			uris = meta.ToURIs
+		}
+		items = append(items, knativeutil.FilterURIs(uris, cst)...)
+		return true
+	}); err != nil {
+		return nil, err
+	}
+
+	sort.Strings(items)
+	return items, nil
 }
 
 func (t *knativeTrait) Apply(e *Environment) error {
-	if pointer.BoolDeref(t.SinkBinding, false) {
-		util.StringSliceUniqueAdd(&e.Integration.Status.Dependencies, "camel:knative")
-		util.StringSliceUniqueAdd(&e.Integration.Status.Dependencies, "mvn:org.apache.camel.k:camel-k-knative-impl")
+	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
+		util.StringSliceUniqueAdd(&e.Integration.Status.Capabilities, v1.CapabilityKnative)
 	}
 
 	if len(t.ChannelSources) > 0 || len(t.EndpointSources) > 0 || len(t.EventSources) > 0 {
@@ -199,7 +179,6 @@ func (t *knativeTrait) Apply(e *Environment) error {
 				return err
 			}
 		}
-
 		if err := t.configureChannels(e, &env); err != nil {
 			return err
 		}
@@ -212,13 +191,12 @@ func (t *knativeTrait) Apply(e *Environment) error {
 		if err := t.configureSinkBinding(e, &env); err != nil {
 			return err
 		}
-
-		conf, err := env.Serialize()
-		if err != nil {
-			return fmt.Errorf("unable to fetch environment configuration: %w", err)
+		if e.ApplicationProperties == nil {
+			e.ApplicationProperties = make(map[string]string)
+		}
+		for k, v := range env.ToCamelProperties() {
+			e.ApplicationProperties[k] = v
 		}
-
-		envvar.SetVal(&e.EnvVars, "CAMEL_KNATIVE_CONFIGURATION", conf)
 	}
 
 	return nil
@@ -260,25 +238,23 @@ func (t *knativeTrait) configureChannels(e *Environment, env *knativeapi.CamelEn
 		return err
 	}
 
-	if !pointer.BoolDeref(t.SinkBinding, false) {
-		// Sinks
-		err = t.ifServiceMissingDo(e, env, t.ChannelSinks, knativeapi.CamelServiceTypeChannel, knativeapi.CamelEndpointKindSink,
-			func(ref *corev1.ObjectReference, serviceURI string, urlProvider func() (*url.URL, error)) error {
-				loc, err := urlProvider()
-				if err != nil {
-					return err
-				}
-				svc, err := knativeapi.BuildCamelServiceDefinition(ref.Name, knativeapi.CamelEndpointKindSink,
-					knativeapi.CamelServiceTypeChannel, *loc, ref.APIVersion, ref.Kind)
-				if err != nil {
-					return err
-				}
-				env.Services = append(env.Services, svc)
-				return nil
-			})
-		if err != nil {
-			return err
-		}
+	// Sinks
+	err = t.ifServiceMissingDo(e, env, t.ChannelSinks, knativeapi.CamelServiceTypeChannel, knativeapi.CamelEndpointKindSink,
+		func(ref *corev1.ObjectReference, serviceURI string, urlProvider func() (*url.URL, error)) error {
+			loc, err := urlProvider()
+			if err != nil {
+				return err
+			}
+			svc, err := knativeapi.BuildCamelServiceDefinition(ref.Name, knativeapi.CamelEndpointKindSink,
+				knativeapi.CamelServiceTypeChannel, *loc, ref.APIVersion, ref.Kind)
+			if err != nil {
+				return err
+			}
+			env.Services = append(env.Services, svc)
+			return nil
+		})
+	if err != nil {
+		return err
 	}
 
 	return nil
@@ -320,24 +296,22 @@ func (t *knativeTrait) configureEndpoints(e *Environment, env *knativeapi.CamelE
 	}
 
 	// Sinks
-	if !pointer.BoolDeref(t.SinkBinding, false) {
-		err := t.ifServiceMissingDo(e, env, t.EndpointSinks, knativeapi.CamelServiceTypeEndpoint, knativeapi.CamelEndpointKindSink,
-			func(ref *corev1.ObjectReference, serviceURI string, urlProvider func() (*url.URL, error)) error {
-				loc, err := urlProvider()
-				if err != nil {
-					return err
-				}
-				svc, err := knativeapi.BuildCamelServiceDefinition(ref.Name, knativeapi.CamelEndpointKindSink,
-					knativeapi.CamelServiceTypeEndpoint, *loc, ref.APIVersion, ref.Kind)
-				if err != nil {
-					return err
-				}
-				env.Services = append(env.Services, svc)
-				return nil
-			})
-		if err != nil {
-			return err
-		}
+	err := t.ifServiceMissingDo(e, env, t.EndpointSinks, knativeapi.CamelServiceTypeEndpoint, knativeapi.CamelEndpointKindSink,
+		func(ref *corev1.ObjectReference, serviceURI string, urlProvider func() (*url.URL, error)) error {
+			loc, err := urlProvider()
+			if err != nil {
+				return err
+			}
+			svc, err := knativeapi.BuildCamelServiceDefinition(ref.Name, knativeapi.CamelEndpointKindSink,
+				knativeapi.CamelServiceTypeEndpoint, *loc, ref.APIVersion, ref.Kind)
+			if err != nil {
+				return err
+			}
+			env.Services = append(env.Services, svc)
+			return nil
+		})
+	if err != nil {
+		return err
 	}
 
 	return nil
@@ -379,24 +353,22 @@ func (t *knativeTrait) configureEvents(e *Environment, env *knativeapi.CamelEnvi
 	}
 
 	// Sinks
-	if !pointer.BoolDeref(t.SinkBinding, false) {
-		err = t.ifServiceMissingDo(e, env, t.EventSinks, knativeapi.CamelServiceTypeEvent, knativeapi.CamelEndpointKindSink,
-			func(ref *corev1.ObjectReference, serviceURI string, urlProvider func() (*url.URL, error)) error {
-				loc, err := urlProvider()
-				if err != nil {
-					return err
-				}
-				svc, err := knativeapi.BuildCamelServiceDefinition(ref.Name, knativeapi.CamelEndpointKindSink,
-					knativeapi.CamelServiceTypeEvent, *loc, ref.APIVersion, ref.Kind)
-				if err != nil {
-					return err
-				}
-				env.Services = append(env.Services, svc)
-				return nil
-			})
-		if err != nil {
-			return err
-		}
+	err = t.ifServiceMissingDo(e, env, t.EventSinks, knativeapi.CamelServiceTypeEvent, knativeapi.CamelEndpointKindSink,
+		func(ref *corev1.ObjectReference, serviceURI string, urlProvider func() (*url.URL, error)) error {
+			loc, err := urlProvider()
+			if err != nil {
+				return err
+			}
+			svc, err := knativeapi.BuildCamelServiceDefinition(ref.Name, knativeapi.CamelEndpointKindSink,
+				knativeapi.CamelServiceTypeEvent, *loc, ref.APIVersion, ref.Kind)
+			if err != nil {
+				return err
+			}
+			env.Services = append(env.Services, svc)
+			return nil
+		})
+	if err != nil {
+		return err
 	}
 
 	return nil
@@ -442,12 +414,8 @@ func (t *knativeTrait) configureSinkBinding(e *Environment, env *knativeapi.Came
 	}
 
 	err := t.withServiceDo(false, e, env, services, serviceType, knativeapi.CamelEndpointKindSink, func(ref *corev1.ObjectReference, serviceURI string, _ func() (*url.URL, error)) error {
-		e.ApplicationProperties["camel.k.customizer.sinkbinding.enabled"] = "true"
-		e.ApplicationProperties["camel.k.customizer.sinkbinding.name"] = ref.Name
-		e.ApplicationProperties["camel.k.customizer.sinkbinding.type"] = string(serviceType)
-		e.ApplicationProperties["camel.k.customizer.sinkbinding.kind"] = ref.Kind
-		e.ApplicationProperties["camel.k.customizer.sinkbinding.api-version"] = ref.APIVersion
-
+		// Mark the service which will be used as SinkBinding
+		env.SetSinkBinding(ref.Name, knativeapi.CamelEndpointKindSink, serviceType, ref.APIVersion, ref.Kind)
 		if e.IntegrationInPhase(v1.IntegrationPhaseDeploying, v1.IntegrationPhaseRunning) {
 			e.PostStepProcessors = append(e.PostStepProcessors, func(e *Environment) error {
 				sinkBindingInjected := false
