@@ -18,9 +18,13 @@ limitations under the License.
 package trait
 
 import (
+	"fmt"
+	"net/url"
+	"regexp"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -38,14 +42,13 @@ import (
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
-	"github.com/apache/camel-k/v2/pkg/util/envvar"
 	k8sutils "github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/test"
 )
 
 func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	traitCatalog := NewCatalog(nil)
 
@@ -101,27 +104,24 @@ func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	c, err := NewFakeClient("ns")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	tc := NewCatalog(c)
 
 	err = tc.Configure(&environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	tr, _ := tc.GetTrait("knative").(*knativeTrait)
-	ok, err := tr.Configure(&environment)
-	assert.Nil(t, err)
+	ok, condition, err := tr.Configure(&environment)
+	require.NoError(t, err)
 	assert.True(t, ok)
+	assert.Nil(t, condition)
 
 	err = tr.Apply(&environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	kc := envvar.Get(environment.EnvVars, "CAMEL_KNATIVE_CONFIGURATION")
-	assert.NotNil(t, kc)
-
-	ne := knativeapi.NewCamelEnvironment()
-	err = ne.Deserialize(kc.Value)
-	assert.Nil(t, err)
+	ne, err := fromCamelProperties(environment.ApplicationProperties)
+	require.NoError(t, err)
 
 	cSource1 := ne.FindService("channel-source-1", knativeapi.CamelEndpointKindSource, knativeapi.CamelServiceTypeChannel, "messaging.knative.dev/v1", "Channel")
 	assert.NotNil(t, cSource1)
@@ -151,7 +151,7 @@ func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 
 func TestKnativeEnvConfigurationFromSource(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	traitCatalog := NewCatalog(nil)
 
@@ -221,28 +221,25 @@ func TestKnativeEnvConfigurationFromSource(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	c, err := NewFakeClient("ns")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	tc := NewCatalog(c)
 
 	err = tc.Configure(&environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	tr, _ := tc.GetTrait("knative").(*knativeTrait)
 
-	ok, err := tr.Configure(&environment)
-	assert.Nil(t, err)
+	ok, condition, err := tr.Configure(&environment)
+	require.NoError(t, err)
 	assert.True(t, ok)
+	assert.Nil(t, condition)
 
 	err = tr.Apply(&environment)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	kc := envvar.Get(environment.EnvVars, "CAMEL_KNATIVE_CONFIGURATION")
-	assert.NotNil(t, kc)
-
-	ne := knativeapi.NewCamelEnvironment()
-	err = ne.Deserialize(kc.Value)
-	assert.Nil(t, err)
+	ne, err := fromCamelProperties(environment.ApplicationProperties)
+	require.NoError(t, err)
 
 	source := ne.FindService("s3fileMover1", knativeapi.CamelEndpointKindSource, knativeapi.CamelServiceTypeEndpoint, "serving.knative.dev/v1", "Service")
 	assert.NotNil(t, source)
@@ -289,16 +286,15 @@ func TestKnativePlatformHttpConfig(t *testing.T) {
 			environment := NewFakeEnvironment(t, source)
 
 			c, err := NewFakeClient("ns")
-			assert.Nil(t, err)
+			require.NoError(t, err)
 
 			tc := NewCatalog(c)
 
 			err = tc.Configure(&environment)
-			assert.Nil(t, err)
-
-			err = tc.apply(&environment)
-			assert.Nil(t, err)
+			require.NoError(t, err)
 
+			_, err = tc.apply(&environment)
+			require.NoError(t, err)
 			assert.Contains(t, environment.Integration.Status.Capabilities, v1.CapabilityPlatformHTTP)
 		})
 	}
@@ -336,28 +332,164 @@ func TestKnativePlatformHttpDependencies(t *testing.T) {
 			environment.Integration.Status.Phase = v1.IntegrationPhaseInitialization
 
 			c, err := NewFakeClient("ns")
-			assert.Nil(t, err)
+			require.NoError(t, err)
 
 			tc := NewCatalog(c)
 
 			err = tc.Configure(&environment)
-			assert.Nil(t, err)
-
-			err = tc.apply(&environment)
-			assert.Nil(t, err)
+			require.NoError(t, err)
 
+			conditions, err := tc.apply(&environment)
+			require.NoError(t, err)
+			assert.NotEmpty(t, conditions)
 			assert.Contains(t, environment.Integration.Status.Capabilities, v1.CapabilityPlatformHTTP)
 			assert.Contains(t, environment.Integration.Status.Dependencies, "mvn:org.apache.camel.quarkus:camel-quarkus-platform-http")
 		})
 	}
 }
 
+func TestKnativeEnabled(t *testing.T) {
+	catalog, err := camel.DefaultCatalog()
+	require.NoError(t, err)
+
+	traitCatalog := NewCatalog(nil)
+
+	environment := Environment{
+		CamelCatalog: catalog,
+		Catalog:      traitCatalog,
+		Integration: &v1.Integration{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "test",
+				Namespace: "ns",
+			},
+			Status: v1.IntegrationStatus{
+				Phase: v1.IntegrationPhaseInitialization,
+			},
+			Spec: v1.IntegrationSpec{
+				Profile: v1.TraitProfileKnative,
+				Sources: []v1.SourceSpec{
+					{
+						DataSpec: v1.DataSpec{
+							Name:    "route.groovy",
+							Content: `from('timer:foo').to('knative:channel/channel-source-1')`,
+						},
+						Language: v1.LanguageGroovy,
+					},
+				},
+			},
+		},
+		Platform: &v1.IntegrationPlatform{
+			Spec: v1.IntegrationPlatformSpec{
+				Cluster: v1.IntegrationPlatformClusterOpenShift,
+				Build: v1.IntegrationPlatformBuildSpec{
+					PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
+					Registry:        v1.RegistrySpec{Address: "registry"},
+				},
+				Profile: v1.TraitProfileKnative,
+			},
+		},
+		EnvVars:        make([]corev1.EnvVar, 0),
+		ExecutedTraits: make([]Trait, 0),
+		Resources:      k8sutils.NewCollection(),
+	}
+	environment.Platform.ResyncStatusFullConfig()
+
+	// configure the init trait
+	init := NewInitTrait()
+	ok, condition, err := init.Configure(&environment)
+	require.NoError(t, err)
+	assert.True(t, ok)
+	assert.Nil(t, condition)
+
+	// apply the init trait
+	require.NoError(t, init.Apply(&environment))
+
+	// configure the knative trait
+	knTrait, _ := newKnativeTrait().(*knativeTrait)
+	ok, condition, err = knTrait.Configure(&environment)
+	require.NoError(t, err)
+	assert.True(t, ok)
+	assert.Nil(t, condition)
+
+	// apply the knative trait
+	require.NoError(t, knTrait.Apply(&environment))
+
+	assert.True(t, *knTrait.Enabled)
+	assert.Contains(t, environment.Integration.Status.Capabilities, v1.CapabilityKnative)
+}
+
+func TestKnativeNotEnabled(t *testing.T) {
+	catalog, err := camel.DefaultCatalog()
+	require.NoError(t, err)
+
+	traitCatalog := NewCatalog(nil)
+
+	environment := Environment{
+		CamelCatalog: catalog,
+		Catalog:      traitCatalog,
+		Integration: &v1.Integration{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "test",
+				Namespace: "ns",
+			},
+			Status: v1.IntegrationStatus{
+				Phase: v1.IntegrationPhaseInitialization,
+			},
+			Spec: v1.IntegrationSpec{
+				Profile: v1.TraitProfileKnative,
+				Sources: []v1.SourceSpec{
+					{
+						DataSpec: v1.DataSpec{
+							Name:    "route.groovy",
+							Content: `from('timer:foo').to('log:info')`,
+						},
+						Language: v1.LanguageGroovy,
+					},
+				},
+			},
+		},
+		Platform: &v1.IntegrationPlatform{
+			Spec: v1.IntegrationPlatformSpec{
+				Cluster: v1.IntegrationPlatformClusterOpenShift,
+				Build: v1.IntegrationPlatformBuildSpec{
+					PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyS2I,
+					Registry:        v1.RegistrySpec{Address: "registry"},
+				},
+				Profile: v1.TraitProfileKnative,
+			},
+		},
+		EnvVars:        make([]corev1.EnvVar, 0),
+		ExecutedTraits: make([]Trait, 0),
+		Resources:      k8sutils.NewCollection(),
+	}
+	environment.Platform.ResyncStatusFullConfig()
+
+	// configure the init trait
+	init := NewInitTrait()
+	ok, condition, err := init.Configure(&environment)
+	require.NoError(t, err)
+	assert.True(t, ok)
+	assert.Nil(t, condition)
+
+	// apply the init trait
+	require.NoError(t, init.Apply(&environment))
+
+	// configure the knative trait
+	knTrait, _ := newKnativeTrait().(*knativeTrait)
+	ok, condition, err = knTrait.Configure(&environment)
+	require.NoError(t, err)
+	assert.False(t, ok)
+	assert.Nil(t, condition)
+
+	assert.NotContains(t, environment.Integration.Status.Capabilities, v1.CapabilityKnative)
+}
+
 func NewFakeEnvironment(t *testing.T, source v1.SourceSpec) Environment {
 	t.Helper()
 
 	client, _ := NewFakeClient("ns")
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	traitCatalog := NewCatalog(nil)
 
@@ -555,3 +687,66 @@ func NewFakeClient(namespace string) (client.Client, error) {
 		},
 	)
 }
+
+func TestKnativeSinkBinding(t *testing.T) {
+	source := v1.SourceSpec{
+		DataSpec: v1.DataSpec{
+			Name:    "sink.groovy",
+			Content: `from('timer:foo').to('knative:channel/channel-sink-1?apiVersion=messaging.knative.dev%2Fv1&kind=Channel')`,
+		},
+		Language: v1.LanguageGroovy,
+	}
+
+	environment := NewFakeEnvironment(t, source)
+	environment.Integration.Status.Phase = v1.IntegrationPhaseDeploying
+
+	c, err := NewFakeClient("ns")
+	require.NoError(t, err)
+
+	tc := NewCatalog(c)
+
+	err = tc.Configure(&environment)
+	require.NoError(t, err)
+
+	_, err = tc.apply(&environment)
+	require.NoError(t, err)
+	baseProp := "camel.component.knative.environment.resources[0]"
+	assert.Equal(t, "channel-sink-1", environment.ApplicationProperties[baseProp+".name"])
+	assert.Equal(t, "${K_SINK}", environment.ApplicationProperties[baseProp+".url"])
+	assert.Equal(t, "${K_CE_OVERRIDES}", environment.ApplicationProperties[baseProp+".ceOverrides"])
+	assert.Equal(t, "channel", environment.ApplicationProperties[baseProp+".type"])
+	assert.Equal(t, "Channel", environment.ApplicationProperties[baseProp+".objectKind"])
+	assert.Equal(t, "messaging.knative.dev/v1", environment.ApplicationProperties[baseProp+".objectApiVersion"])
+	assert.Equal(t, "sink", environment.ApplicationProperties[baseProp+".endpointKind"])
+}
+
+// fromCamelProperties deserialize from properties to environment.
+func fromCamelProperties(appProps map[string]string) (*knativeapi.CamelEnvironment, error) {
+	env := knativeapi.NewCamelEnvironment()
+	re := regexp.MustCompile(`camel.component.knative.environment.resources\[(\d+)\].name`)
+	for k, v := range appProps {
+		if re.MatchString(k) {
+			index := re.FindStringSubmatch(k)[1]
+			baseComp := fmt.Sprintf("camel.component.knative.environment.resources[%s]", index)
+			url, err := url.Parse(appProps[fmt.Sprintf("%s.url", baseComp)])
+			if err != nil {
+				return nil, err
+			}
+			svc, err := knativeapi.BuildCamelServiceDefinition(
+				v,
+				knativeapi.CamelEndpointKind(appProps[fmt.Sprintf("%s.endpointKind", baseComp)]),
+				knativeapi.CamelServiceType(appProps[fmt.Sprintf("%s.type", baseComp)]),
+				*url,
+				appProps[fmt.Sprintf("%s.objectApiVersion", baseComp)],
+				appProps[fmt.Sprintf("%s.objectKind", baseComp)],
+			)
+			if err != nil {
+				return nil, err
+			}
+			svc.Metadata[knativeapi.CamelMetaKnativeReply] = appProps[fmt.Sprintf("%s.reply", baseComp)]
+			env.Services = append(env.Services, svc)
+		}
+	}
+
+	return &env, nil
+}
