@@ -25,9 +25,10 @@ import (
 )
 
 const (
-	envVarQuarkusLogLevel                  = "QUARKUS_LOG_LEVEL"
-	envVarQuarkusLogConsoleColor           = "QUARKUS_LOG_CONSOLE_COLOR"
-	envVarQuarkusLogConsoleFormat          = "QUARKUS_LOG_CONSOLE_FORMAT"
+	envVarQuarkusConsoleColor     = "QUARKUS_CONSOLE_COLOR"
+	envVarQuarkusLogLevel         = "QUARKUS_LOG_LEVEL"
+	envVarQuarkusLogConsoleFormat = "QUARKUS_LOG_CONSOLE_FORMAT"
+	// nolint: gosec // no sensitive credentials
 	envVarQuarkusLogConsoleJSON            = "QUARKUS_LOG_CONSOLE_JSON"
 	envVarQuarkusLogConsoleJSONPrettyPrint = "QUARKUS_LOG_CONSOLE_JSON_PRETTY_PRINT"
 	defaultLogLevel                        = "INFO"
@@ -47,15 +48,30 @@ func newLoggingTraitTrait() Trait {
 	}
 }
 
-func (l loggingTrait) Configure(e *Environment) (bool, error) {
-	if e.Integration == nil || !pointer.BoolDeref(l.Enabled, true) {
-		return false, nil
+func (l loggingTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	if e.Integration == nil {
+		return false, nil, nil
 	}
 
-	return e.IntegrationInRunningPhases(), nil
+	if !pointer.BoolDeref(l.Enabled, true) {
+		return false, NewIntegrationConditionUserDisabled("Logging"), nil
+	}
+
+	return e.IntegrationInRunningPhases(), nil, nil
 }
 
 func (l loggingTrait) Apply(e *Environment) error {
+	if e.CamelCatalog.Runtime.Capabilities["logging"].RuntimeProperties != nil {
+		l.setCatalogConfiguration(e)
+	} else {
+		l.setEnvConfiguration(e)
+	}
+
+	return nil
+}
+
+// Deprecated: to be removed in future release in favor of func setCatalogConfiguration().
+func (l loggingTrait) setEnvConfiguration(e *Environment) {
 	envvar.SetVal(&e.EnvVars, envVarQuarkusLogLevel, l.Level)
 
 	if l.Format != "" {
@@ -72,9 +88,35 @@ func (l loggingTrait) Apply(e *Environment) error {
 		envvar.SetVal(&e.EnvVars, envVarQuarkusLogConsoleJSON, False)
 
 		if pointer.BoolDeref(l.Color, true) {
-			envvar.SetVal(&e.EnvVars, envVarQuarkusLogConsoleColor, True)
+			envvar.SetVal(&e.EnvVars, envVarQuarkusConsoleColor, True)
+		}
+	}
+}
+
+func (l loggingTrait) setCatalogConfiguration(e *Environment) {
+	if e.ApplicationProperties == nil {
+		e.ApplicationProperties = make(map[string]string)
+	}
+	e.ApplicationProperties["camel.k.logging.level"] = l.Level
+	if l.Format != "" {
+		e.ApplicationProperties["camel.k.logging.format"] = l.Format
+	}
+	if pointer.BoolDeref(l.JSON, false) {
+		e.ApplicationProperties["camel.k.logging.json"] = True
+		if pointer.BoolDeref(l.JSONPrettyPrint, false) {
+			e.ApplicationProperties["camel.k.logging.jsonPrettyPrint"] = True
+		}
+	} else {
+		// If the trait is false OR unset, we default to false.
+		e.ApplicationProperties["camel.k.logging.json"] = False
+		if pointer.BoolDeref(l.Color, true) {
+			e.ApplicationProperties["camel.k.logging.color"] = True
 		}
 	}
 
-	return nil
+	for _, cp := range e.CamelCatalog.Runtime.Capabilities["logging"].RuntimeProperties {
+		if CapabilityPropertyKey(cp.Value, e.ApplicationProperties) != "" {
+			e.ApplicationProperties[CapabilityPropertyKey(cp.Key, e.ApplicationProperties)] = cp.Value
+		}
+	}
 }
