@@ -25,7 +25,6 @@ import (
 	appsv1 "k8s.io/api/apps/v1"
 	batchv1 "k8s.io/api/batch/v1"
 	corev1 "k8s.io/api/core/v1"
-	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/utils/pointer"
 
 	serving "knative.dev/serving/pkg/apis/serving/v1"
@@ -37,47 +36,47 @@ import (
 )
 
 type mountTrait struct {
-	BaseTrait
+	BasePlatformTrait
 	traitv1.MountTrait `property:",squash"`
 }
 
 func newMountTrait() Trait {
 	return &mountTrait{
 		// Must follow immediately the container trait
-		BaseTrait: NewBaseTrait("mount", 1610),
+		BasePlatformTrait: NewBasePlatformTrait("mount", 1610),
 	}
 }
 
-func (t *mountTrait) Configure(e *Environment) (bool, error) {
-	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
-		return false, nil
+func (t *mountTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	if e.Integration == nil || !e.IntegrationInRunningPhases() {
+		return false, nil, nil
 	}
+	// Look for secrets which may have been created by service binding trait
+	t.addServiceBindingSecret(e)
 
-	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) ||
-		(!e.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !e.IntegrationInRunningPhases()) {
-		return false, nil
-	}
+	// Look for implicit secrets which may be required by kamelets
+	condition := t.addImplicitKameletsSecrets(e)
 
 	// Validate resources and pvcs
 	for _, c := range t.Configs {
 		if !strings.HasPrefix(c, "configmap:") && !strings.HasPrefix(c, "secret:") {
-			return false, fmt.Errorf("unsupported config %s, must be a configmap or secret resource", c)
+			return false, nil, fmt.Errorf("unsupported config %s, must be a configmap or secret resource", c)
 		}
 	}
 	for _, r := range t.Resources {
 		if !strings.HasPrefix(r, "configmap:") && !strings.HasPrefix(r, "secret:") {
-			return false, fmt.Errorf("unsupported resource %s, must be a configmap or secret resource", r)
+			return false, nil, fmt.Errorf("unsupported resource %s, must be a configmap or secret resource", r)
 		}
 	}
 
-	return true, nil
+	// mount trait needs to be executed only when it has sources attached or any trait configuration
+	return len(e.Integration.AllSources()) > 0 ||
+		len(t.Configs) > 0 ||
+		len(t.Resources) > 0 ||
+		len(t.Volumes) > 0, condition, nil
 }
 
 func (t *mountTrait) Apply(e *Environment) error {
-	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
-		return nil
-	}
-
 	container := e.GetIntegrationContainer()
 	if container == nil {
 		return fmt.Errorf("unable to find integration container: %s", e.Integration.Name)
@@ -117,7 +116,7 @@ func (t *mountTrait) Apply(e *Environment) error {
 		// Volumes declared in the Integration resources
 		e.configureVolumesAndMounts(volumes, &container.VolumeMounts)
 		// Volumes declared in the trait config/resource options
-		err := t.configureVolumesAndMounts(e, volumes, &container.VolumeMounts)
+		err := t.configureVolumesAndMounts(volumes, &container.VolumeMounts)
 		if err != nil {
 			return err
 		}
@@ -126,10 +125,9 @@ func (t *mountTrait) Apply(e *Environment) error {
 	return nil
 }
 
-func (t *mountTrait) configureVolumesAndMounts(e *Environment, vols *[]corev1.Volume, mnts *[]corev1.VolumeMount) error {
+func (t *mountTrait) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]corev1.VolumeMount) error {
 	for _, c := range t.Configs {
 		if conf, parseErr := utilResource.ParseConfig(c); parseErr == nil {
-			t.attachResource(e, conf)
 			t.mountResource(vols, mnts, conf)
 		} else {
 			return parseErr
@@ -137,7 +135,6 @@ func (t *mountTrait) configureVolumesAndMounts(e *Environment, vols *[]corev1.Vo
 	}
 	for _, r := range t.Resources {
 		if res, parseErr := utilResource.ParseResource(r); parseErr == nil {
-			t.attachResource(e, res)
 			t.mountResource(vols, mnts, res)
 		} else {
 			return parseErr
@@ -154,20 +151,6 @@ func (t *mountTrait) configureVolumesAndMounts(e *Environment, vols *[]corev1.Vo
 	return nil
 }
 
-// attachResource is in charge to filter the autogenerated configmap and attach to the Integration resources.
-// The owner trait will be in charge to bind it accordingly.
-func (t *mountTrait) attachResource(e *Environment, conf *utilResource.Config) {
-	if conf.StorageType() == utilResource.StorageTypeConfigmap {
-		// verify if it was autogenerated
-		cm, err := kubernetes.GetUnstructured(e.Ctx, e.Client, schema.GroupVersionKind{Group: "", Version: "v1", Kind: "ConfigMap"},
-			conf.Name(), e.Integration.Namespace)
-		if err == nil && cm != nil && cm.GetLabels()[kubernetes.ConfigMapAutogenLabel] == "true" {
-			refCm := kubernetes.NewConfigMap(e.Integration.Namespace, conf.Name(), "", "", "", nil)
-			e.Resources.Add(refCm)
-		}
-	}
-}
-
 func (t *mountTrait) mountResource(vols *[]corev1.Volume, mnts *[]corev1.VolumeMount, conf *utilResource.Config) {
 	refName := kubernetes.SanitizeLabel(conf.Name())
 	dstDir := conf.DestinationPath()
@@ -191,7 +174,56 @@ func (t *mountTrait) mountResource(vols *[]corev1.Volume, mnts *[]corev1.VolumeM
 	*mnts = append(*mnts, *mnt)
 }
 
-// IsPlatformTrait overrides base class method.
-func (t *mountTrait) IsPlatformTrait() bool {
-	return true
+func (t *mountTrait) addServiceBindingSecret(e *Environment) {
+	e.Resources.VisitSecret(func(secret *corev1.Secret) {
+		if secret.Labels[serviceBindingLabel] == "true" {
+			t.Configs = append(t.Configs, "secret:"+secret.Name)
+		}
+	})
+}
+
+// Deprecated: to be removed in future releases.
+// nolint: staticcheck
+func (t *mountTrait) addImplicitKameletsSecrets(e *Environment) *TraitCondition {
+	featureUsed := false
+	if trait := e.Catalog.GetTrait(kameletsTraitID); trait != nil {
+		kamelets, ok := trait.(*kameletsTrait)
+		if !ok {
+			return NewIntegrationCondition(
+				"Mount",
+				v1.IntegrationConditionTraitInfo,
+				corev1.ConditionTrue,
+				traitConfigurationReason,
+				"Unexpected error happened while casting to kamelets trait",
+			)
+		}
+		if !pointer.BoolDeref(t.ScanKameletsImplicitLabelSecrets, true) {
+			return nil
+		}
+		implicitKameletSecrets, err := kamelets.listConfigurationSecrets(e)
+		if err != nil {
+			return NewIntegrationCondition(
+				"Mount",
+				v1.IntegrationConditionTraitInfo,
+				corev1.ConditionTrue,
+				traitConfigurationReason,
+				err.Error(),
+			)
+		}
+		for _, secret := range implicitKameletSecrets {
+			featureUsed = true
+			t.Configs = append(t.Configs, "secret:"+secret)
+		}
+	}
+
+	if featureUsed {
+		return NewIntegrationCondition(
+			"Mount",
+			v1.IntegrationConditionTraitInfo,
+			corev1.ConditionTrue,
+			traitConfigurationReason,
+			"Implicit Kamelet labelling secrets are deprecated and may be removed in future releases. Make sure to use explicit mount.config secrets instead.",
+		)
+	}
+	return nil
 }
