@@ -36,16 +36,24 @@ import (
 )
 
 const (
-	quarkusTraitID = "quarkus"
+	quarkusTraitID                    = "quarkus"
+	QuarkusNativeDefaultBaseImageName = "quay.io/quarkus/quarkus-micro-image:2.0"
 )
 
-var kitPriority = map[traitv1.QuarkusPackageType]string{
-	traitv1.FastJarPackageType: "1000",
-	traitv1.NativePackageType:  "2000",
+type quarkusPackageType string
+
+const (
+	fastJarPackageType       quarkusPackageType = "fast-jar"
+	nativeSourcesPackageType quarkusPackageType = "native-sources"
+)
+
+var kitPriority = map[quarkusPackageType]string{
+	fastJarPackageType:       "1000",
+	nativeSourcesPackageType: "2000",
 }
 
 type quarkusTrait struct {
-	BaseTrait
+	BasePlatformTrait
 	traitv1.QuarkusTrait `property:",squash"`
 }
 type languageSettings struct {
@@ -92,63 +100,71 @@ func getLegacyLanguageSettings(language v1.Language) languageSettings {
 
 func newQuarkusTrait() Trait {
 	return &quarkusTrait{
-		BaseTrait: NewBaseTrait(quarkusTraitID, 1700),
+		BasePlatformTrait: NewBasePlatformTrait(quarkusTraitID, 1700),
 	}
 }
 
-// IsPlatformTrait overrides base class method.
-func (t *quarkusTrait) IsPlatformTrait() bool {
-	return true
-}
-
 // InfluencesKit overrides base class method.
 func (t *quarkusTrait) InfluencesKit() bool {
 	return true
 }
 
-// InfluencesBuild overrides base class method.
-func (t *quarkusTrait) InfluencesBuild(this, prev map[string]interface{}) bool {
-	return true
-}
-
-var _ ComparableTrait = &quarkusTrait{}
-
 func (t *quarkusTrait) Matches(trait Trait) bool {
 	qt, ok := trait.(*quarkusTrait)
 	if !ok {
 		return false
 	}
-
-	if pointer.BoolDeref(t.Enabled, true) && !pointer.BoolDeref(qt.Enabled, true) {
+	if len(t.Modes) == 0 && len(qt.Modes) != 0 && !qt.containsMode(traitv1.JvmQuarkusMode) {
 		return false
 	}
-
-	if len(t.PackageTypes) == 0 && len(qt.PackageTypes) != 0 && !containsPackageType(qt.PackageTypes, traitv1.FastJarPackageType) {
-		return false
-	}
-
-	for _, pt := range t.PackageTypes {
-		if pt == traitv1.FastJarPackageType && len(qt.PackageTypes) == 0 {
+	for _, md := range t.Modes {
+		if md == traitv1.JvmQuarkusMode && len(qt.Modes) == 0 {
 			continue
 		}
-		if containsPackageType(qt.PackageTypes, pt) {
+		if qt.containsMode(md) {
 			continue
 		}
 		return false
 	}
+	// We need to check if the native base image used is the same
+	thisNativeBaseImage := t.NativeBaseImage
+	if thisNativeBaseImage == "" {
+		thisNativeBaseImage = QuarkusNativeDefaultBaseImageName
+	}
+	otherNativeBaseImage := qt.NativeBaseImage
+	if otherNativeBaseImage == "" {
+		otherNativeBaseImage = QuarkusNativeDefaultBaseImageName
+	}
 
-	return true
+	return thisNativeBaseImage == otherNativeBaseImage
 }
 
-func (t *quarkusTrait) Configure(e *Environment) (bool, error) {
-	if !pointer.BoolDeref(t.Enabled, true) {
-		return false, nil
-	}
+func (t *quarkusTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	condition := t.adaptDeprecatedFields()
 
 	return e.IntegrationInPhase(v1.IntegrationPhaseBuildingKit) ||
 			e.IntegrationKitInPhase(v1.IntegrationKitPhaseBuildSubmitted) ||
 			e.IntegrationKitInPhase(v1.IntegrationKitPhaseReady) && e.IntegrationInRunningPhases(),
-		nil
+		condition, nil
+}
+
+func (t *quarkusTrait) adaptDeprecatedFields() *TraitCondition {
+	if t.PackageTypes != nil {
+		message := "The package-type parameter is deprecated and may be removed in future releases. Make sure to use mode parameter instead."
+		t.L.Info(message)
+		for _, pt := range t.PackageTypes {
+			if pt == traitv1.NativePackageType {
+				t.Modes = append(t.Modes, traitv1.NativeQuarkusMode)
+				continue
+			}
+			if pt == traitv1.FastJarPackageType {
+				t.Modes = append(t.Modes, traitv1.JvmQuarkusMode)
+			}
+		}
+		return NewIntegrationCondition("Quarkus", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, traitConfigurationReason, message)
+	}
+
+	return nil
 }
 
 func (t *quarkusTrait) Apply(e *Environment) error {
@@ -174,7 +190,7 @@ func (t *quarkusTrait) Apply(e *Environment) error {
 }
 
 func (t *quarkusTrait) applyWhileBuildingKit(e *Environment) {
-	if containsPackageType(t.PackageTypes, traitv1.NativePackageType) {
+	if t.containsMode(traitv1.NativeQuarkusMode) {
 		// Native compilation is only supported for a subset of languages,
 		// so let's check for compatibility, and fail-fast the Integration,
 		// to save compute resources and user time.
@@ -184,30 +200,32 @@ func (t *quarkusTrait) applyWhileBuildingKit(e *Environment) {
 		}
 	}
 
-	switch len(t.PackageTypes) {
+	switch len(t.Modes) {
 	case 0:
-		kit := t.newIntegrationKit(e, traitv1.FastJarPackageType)
+		// Default behavior
+		kit := t.newIntegrationKit(e, fastJarPackageType)
 		e.IntegrationKits = append(e.IntegrationKits, *kit)
-
 	case 1:
-		kit := t.newIntegrationKit(e, t.PackageTypes[0])
+		kit := t.newIntegrationKit(e, packageType(t.Modes[0]))
 		e.IntegrationKits = append(e.IntegrationKits, *kit)
-
 	default:
-		for _, pt := range t.PackageTypes {
-			packageType := pt
-			kit := t.newIntegrationKit(e, packageType)
+		// execute jvm mode before native mode
+		sort.Slice(t.Modes, func(i, j int) bool {
+			return t.Modes[i] != traitv1.NativeQuarkusMode
+		})
+		for _, md := range t.Modes {
+			kit := t.newIntegrationKit(e, packageType(md))
 			if kit.Spec.Traits.Quarkus == nil {
 				kit.Spec.Traits.Quarkus = &traitv1.QuarkusTrait{}
 			}
-			kit.Spec.Traits.Quarkus.PackageTypes = []traitv1.QuarkusPackageType{packageType}
+			kit.Spec.Traits.Quarkus.Modes = []traitv1.QuarkusMode{md}
 			e.IntegrationKits = append(e.IntegrationKits, *kit)
 		}
 	}
 }
 
 func (t *quarkusTrait) validateNativeSupport(e *Environment) bool {
-	for _, source := range e.Integration.Sources() {
+	for _, source := range e.Integration.AllSources() {
 		if language := source.InferLanguage(); !getLanguageSettings(e, language).native {
 			t.L.ForIntegration(e.Integration).Infof("Integration %s/%s contains a %s source that cannot be compiled to native executable", e.Integration.Namespace, e.Integration.Name, language)
 			e.Integration.Status.Phase = v1.IntegrationPhaseError
@@ -224,7 +242,7 @@ func (t *quarkusTrait) validateNativeSupport(e *Environment) bool {
 	return true
 }
 
-func (t *quarkusTrait) newIntegrationKit(e *Environment, packageType traitv1.QuarkusPackageType) *v1.IntegrationKit {
+func (t *quarkusTrait) newIntegrationKit(e *Environment, packageType quarkusPackageType) *v1.IntegrationKit {
 	integration := e.Integration
 	kit := v1.NewIntegrationKit(integration.GetIntegrationKitNamespace(e.Platform), fmt.Sprintf("kit-%s", xid.New()))
 
@@ -244,114 +262,181 @@ func (t *quarkusTrait) newIntegrationKit(e *Environment, packageType traitv1.Qua
 		v1.SetAnnotation(&kit.ObjectMeta, v1.PlatformSelectorAnnotation, v)
 	}
 
+	if v, ok := integration.Annotations[v1.IntegrationProfileAnnotation]; ok {
+		v1.SetAnnotation(&kit.ObjectMeta, v1.IntegrationProfileAnnotation, v)
+
+		if v, ok := e.Integration.Annotations[v1.IntegrationProfileNamespaceAnnotation]; ok {
+			v1.SetAnnotation(&kit.ObjectMeta, v1.IntegrationProfileNamespaceAnnotation, v)
+		} else {
+			// set integration profile namespace to the integration namespace.
+			// this is because the kit may live in another namespace and needs to resolve the integration profile from the integration namespace.
+			v1.SetAnnotation(&kit.ObjectMeta, v1.IntegrationProfileNamespaceAnnotation, e.Integration.Namespace)
+		}
+	}
 	for k, v := range integration.Annotations {
 		if strings.HasPrefix(k, v1.TraitAnnotationPrefix) {
 			v1.SetAnnotation(&kit.ObjectMeta, k, v)
 		}
 	}
-
 	operatorID := defaults.OperatorID()
 	if operatorID != "" {
 		kit.SetOperatorID(operatorID)
 	}
-
 	kit.Spec = v1.IntegrationKitSpec{
 		Dependencies: e.Integration.Status.Dependencies,
 		Repositories: e.Integration.Spec.Repositories,
 		Traits:       propagateKitTraits(e),
 	}
-
-	if packageType == traitv1.NativePackageType {
+	if packageType == nativeSourcesPackageType {
 		kit.Spec.Sources = propagateSourcesRequiredAtBuildTime(e)
 	}
+	if e.Integration.Status.Capabilities != nil {
+		kit.Spec.Capabilities = e.Integration.Status.Capabilities
+	}
 	return kit
 }
 
 func propagateKitTraits(e *Environment) v1.IntegrationKitTraits {
-	traits := e.Integration.Spec.Traits
-	kitTraits := v1.IntegrationKitTraits{
-		Builder:  traits.Builder.DeepCopy(),
-		Camel:    traits.Camel.DeepCopy(),
-		Quarkus:  traits.Quarkus.DeepCopy(),
+	kitTraits := v1.IntegrationKitTraits{}
+
+	if e.Platform != nil {
+		propagate(fmt.Sprintf("platform %q", e.Platform.Name), e.Platform.Status.Traits, &kitTraits, e)
+	}
+
+	if e.IntegrationProfile != nil {
+		propagate(fmt.Sprintf("integration profile %q", e.IntegrationProfile.Name), e.IntegrationProfile.Status.Traits, &kitTraits, e)
+	}
+
+	propagate(fmt.Sprintf("integration %q", e.Integration.Name), e.Integration.Spec.Traits, &kitTraits, e)
+
+	return kitTraits
+}
+
+func propagate(traitSource string, traits v1.Traits, kitTraits *v1.IntegrationKitTraits, e *Environment) {
+	ikt := v1.IntegrationKitTraits{
+		Builder: traits.Builder.DeepCopy(),
+		Camel:   traits.Camel.DeepCopy(),
+		Quarkus: traits.Quarkus.DeepCopy(),
+		// nolint: staticcheck
 		Registry: traits.Registry.DeepCopy(),
 	}
 
+	if err := kitTraits.Merge(ikt); err != nil {
+		log.Errorf(err, "Unable to propagate traits from %s to the integration kit", traitSource)
+	}
+
 	// propagate addons that influence kits too
 	if len(traits.Addons) > 0 {
-		kitTraits.Addons = make(map[string]v1.AddonTrait)
+		if kitTraits.Addons == nil {
+			kitTraits.Addons = make(map[string]v1.AddonTrait)
+		}
+
 		for id, addon := range traits.Addons {
 			if t := e.Catalog.GetTrait(id); t != nil && t.InfluencesKit() {
 				kitTraits.Addons[id] = *addon.DeepCopy()
 			}
 		}
 	}
-
-	return kitTraits
 }
 
 func (t *quarkusTrait) applyWhenBuildSubmitted(e *Environment) error {
-	build := getBuilderTask(e.Pipeline)
-	if build == nil {
+	buildTask := getBuilderTask(e.Pipeline)
+	if buildTask == nil {
 		return fmt.Errorf("unable to find builder task: %s", e.Integration.Name)
 	}
-
-	if build.Maven.Properties == nil {
-		build.Maven.Properties = make(map[string]string)
+	packageTask := getPackageTask(e.Pipeline)
+	if packageTask == nil {
+		return fmt.Errorf("unable to find package task: %s", e.Integration.Name)
 	}
 
-	steps, err := builder.StepsFrom(build.Steps...)
+	buildSteps, err := builder.StepsFrom(buildTask.Steps...)
+	if err != nil {
+		return err
+	}
+	buildSteps = append(buildSteps, builder.Quarkus.CommonSteps...)
+
+	packageSteps, err := builder.StepsFrom(packageTask.Steps...)
 	if err != nil {
 		return err
 	}
 
-	steps = append(steps, builder.Quarkus.CommonSteps...)
+	if buildTask.Maven.Properties == nil {
+		buildTask.Maven.Properties = make(map[string]string)
+	}
 
 	native, err := t.isNativeKit(e)
 	if err != nil {
 		return err
 	}
 
+	// The LoadCamelQuarkusCatalog is required to have catalog information available by the builder
+	packageSteps = append(packageSteps, builder.Quarkus.LoadCamelQuarkusCatalog)
+
 	if native {
-		build.Maven.Properties["quarkus.package.type"] = string(traitv1.NativePackageType)
+		if nativePackageType := builder.QuarkusRuntimeSupport(e.CamelCatalog.GetCamelQuarkusVersion()).NativeMavenProperty(); nativePackageType != "" {
+			buildTask.Maven.Properties["quarkus.package.type"] = nativePackageType
+			if t.NativeBaseImage == "" {
+				packageTask.BaseImage = QuarkusNativeDefaultBaseImageName
+			} else {
+				packageTask.BaseImage = t.NativeBaseImage
+			}
+		}
 		if len(e.IntegrationKit.Spec.Sources) > 0 {
-			build.Sources = e.IntegrationKit.Spec.Sources
-			steps = append(steps, builder.Quarkus.PrepareProjectWithSources)
-		}
-		steps = append(steps, builder.Image.NativeImageContext)
-		// Spectrum does not rely on Dockerfile to assemble the image
-		if e.Platform.Status.Build.PublishStrategy != v1.IntegrationPlatformBuildPublishStrategySpectrum {
-			steps = append(steps, builder.Image.ExecutableDockerfile)
+			buildTask.Sources = e.IntegrationKit.Spec.Sources
+			buildSteps = append(buildSteps, builder.Quarkus.PrepareProjectWithSources)
 		}
+		packageSteps = append(packageSteps, builder.Image.NativeImageContext)
+		// Create the dockerfile, regardless it's later used or not by the publish strategy
+		packageSteps = append(packageSteps, builder.Image.ExecutableDockerfile)
 	} else {
-		build.Maven.Properties["quarkus.package.type"] = string(traitv1.FastJarPackageType)
-		steps = append(steps, builder.Quarkus.ComputeQuarkusDependencies, builder.Image.IncrementalImageContext)
-		// Spectrum does not rely on Dockerfile to assemble the image
-		if e.Platform.Status.Build.PublishStrategy != v1.IntegrationPlatformBuildPublishStrategySpectrum {
-			steps = append(steps, builder.Image.JvmDockerfile)
+		// Default, if nothing is specified
+		buildTask.Maven.Properties["quarkus.package.type"] = string(fastJarPackageType)
+		packageSteps = append(packageSteps, builder.Quarkus.ComputeQuarkusDependencies)
+		if t.isIncrementalImageBuild(e) {
+			packageSteps = append(packageSteps, builder.Image.IncrementalImageContext)
+		} else {
+			packageSteps = append(packageSteps, builder.Image.StandardImageContext)
 		}
+		// Create the dockerfile, regardless it's later used or not by the publish strategy
+		packageSteps = append(packageSteps, builder.Image.JvmDockerfile)
 	}
 
 	// Sort steps by phase
-	sort.SliceStable(steps, func(i, j int) bool {
-		return steps[i].Phase() < steps[j].Phase()
+	sort.SliceStable(buildSteps, func(i, j int) bool {
+		return buildSteps[i].Phase() < buildSteps[j].Phase()
+	})
+	sort.SliceStable(packageSteps, func(i, j int) bool {
+		return packageSteps[i].Phase() < packageSteps[j].Phase()
 	})
 
-	build.Steps = builder.StepIDsFor(steps...)
+	buildTask.Steps = builder.StepIDsFor(buildSteps...)
+	packageTask.Steps = builder.StepIDsFor(packageSteps...)
 
 	return nil
 }
 
 func (t *quarkusTrait) isNativeKit(e *Environment) (bool, error) {
-	switch types := t.PackageTypes; len(types) {
+	switch modes := t.Modes; len(modes) {
 	case 0:
 		return false, nil
 	case 1:
-		return types[0] == traitv1.NativePackageType, nil
+		return modes[0] == traitv1.NativeQuarkusMode, nil
 	default:
 		return false, fmt.Errorf("kit %q has more than one package type", e.IntegrationKit.Name)
 	}
 }
 
+func (t *quarkusTrait) isIncrementalImageBuild(e *Environment) bool {
+	// We need to get this information from the builder trait
+	if trait := e.Catalog.GetTrait(builderTraitID); trait != nil {
+		builder, ok := trait.(*builderTrait)
+		return ok && pointer.BoolDeref(builder.IncrementalImageBuild, true)
+	}
+
+	// Default always to true for performance reasons
+	return true
+}
+
 func (t *quarkusTrait) applyWhenKitReady(e *Environment) error {
 	if e.IntegrationInRunningPhases() && t.isNativeIntegration(e) {
 		container := e.GetIntegrationContainer()
@@ -368,7 +453,7 @@ func (t *quarkusTrait) applyWhenKitReady(e *Environment) error {
 
 func (t *quarkusTrait) isNativeIntegration(e *Environment) bool {
 	// The current IntegrationKit determines the Integration runtime type
-	return e.IntegrationKit.Labels[v1.IntegrationKitLayoutLabel] == v1.IntegrationKitLayoutNative
+	return e.IntegrationKit.Labels[v1.IntegrationKitLayoutLabel] == v1.IntegrationKitLayoutNativeSources
 }
 
 // Indicates whether the given source code is embedded into the final binary.
@@ -382,25 +467,36 @@ func (t *quarkusTrait) isEmbedded(e *Environment, source v1.SourceSpec) bool {
 	return false
 }
 
-func containsPackageType(types []traitv1.QuarkusPackageType, t traitv1.QuarkusPackageType) bool {
-	for _, ti := range types {
-		if t == ti {
+func (t *quarkusTrait) containsMode(m traitv1.QuarkusMode) bool {
+	for _, mode := range t.Modes {
+		if mode == m {
 			return true
 		}
 	}
 	return false
 }
 
+func packageType(mode traitv1.QuarkusMode) quarkusPackageType {
+	if mode == traitv1.NativeQuarkusMode {
+		return nativeSourcesPackageType
+	}
+	if mode == traitv1.JvmQuarkusMode {
+		return fastJarPackageType
+	}
+
+	return ""
+}
+
 // Indicates whether the given source file is required at build time for native compilation.
 func sourcesRequiredAtBuildTime(e *Environment, source v1.SourceSpec) bool {
 	settings := getLanguageSettings(e, source.InferLanguage())
 	return settings.native && settings.sourcesRequiredAtBuildTime
 }
 
-// Propagates the sources that are required at build time for native compilation.
+// Propagates the user defined sources that are required at build time for native compilation.
 func propagateSourcesRequiredAtBuildTime(e *Environment) []v1.SourceSpec {
 	array := make([]v1.SourceSpec, 0)
-	for _, source := range e.Integration.Sources() {
+	for _, source := range e.Integration.UserDefinedSources() {
 		if sourcesRequiredAtBuildTime(e, source) {
 			array = append(array, source)
 		}
