@@ -43,6 +43,9 @@ type routeTrait struct {
 func newRouteTrait() Trait {
 	return &routeTrait{
 		BaseTrait: NewBaseTrait("route", 2200),
+		RouteTrait: traitv1.RouteTrait{
+			Annotations: map[string]string{},
+		},
 	}
 }
 
@@ -51,39 +54,29 @@ func (t *routeTrait) IsAllowedInProfile(profile v1.TraitProfile) bool {
 	return profile.Equal(v1.TraitProfileOpenShift)
 }
 
-func (t *routeTrait) Configure(e *Environment) (bool, error) {
-	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
-		if e.Integration != nil {
-			e.Integration.Status.SetCondition(
-				v1.IntegrationConditionExposureAvailable,
-				corev1.ConditionFalse,
-				v1.IntegrationConditionRouteNotAvailableReason,
-				"explicitly disabled",
-			)
-		}
-
-		return false, nil
+func (t *routeTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	if e.Integration == nil {
+		return false, nil, nil
+	}
+	if !pointer.BoolDeref(t.Enabled, true) {
+		return false, NewIntegrationCondition(
+			"Route",
+			v1.IntegrationConditionExposureAvailable,
+			corev1.ConditionFalse,
+			v1.IntegrationConditionRouteNotAvailableReason,
+			"explicitly disabled",
+		), nil
 	}
-
 	if !e.IntegrationInRunningPhases() {
-		return false, nil
+		return false, nil, nil
 	}
 
 	t.service = e.Resources.GetUserServiceForIntegration(e.Integration)
 	if t.service == nil {
-		if e.Integration != nil {
-			e.Integration.Status.SetCondition(
-				v1.IntegrationConditionExposureAvailable,
-				corev1.ConditionFalse,
-				v1.IntegrationConditionRouteNotAvailableReason,
-				"no target service found",
-			)
-		}
-
-		return false, nil
+		return false, nil, nil
 	}
 
-	return true, nil
+	return true, nil, nil
 }
 
 func (t *routeTrait) Apply(e *Environment) error {
@@ -109,6 +102,7 @@ func (t *routeTrait) Apply(e *Environment) error {
 			Labels: map[string]string{
 				v1.IntegrationLabel: e.Integration.Name,
 			},
+			Annotations: t.Annotations,
 		},
 		Spec: routev1.RouteSpec{
 			Port: &routev1.RoutePort{
