@@ -18,10 +18,12 @@ limitations under the License.
 package trait
 
 import (
+	"reflect"
 	"testing"
 
 	"github.com/rs/xid"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	routev1 "github.com/openshift/api/route/v1"
 
@@ -107,7 +109,7 @@ func createTestRouteEnvironment(t *testing.T, name string) *Environment {
 	t.Helper()
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	client, _ := test.NewFakeClient(
 		&corev1.Secret{
 			TypeMeta: metav1.TypeMeta{
@@ -204,9 +206,9 @@ func TestRoute_Default(t *testing.T) {
 	environment := createTestRouteEnvironment(t, name)
 	traitsCatalog := environment.Catalog
 
-	err := traitsCatalog.apply(environment)
-
-	assert.Nil(t, err)
+	conditions, err := traitsCatalog.apply(environment)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("container"))
 	assert.NotNil(t, environment.GetTrait("route"))
@@ -232,10 +234,17 @@ func TestRoute_Disabled(t *testing.T) {
 		},
 	}
 
+	expectedCondition := NewIntegrationCondition(
+		"Route",
+		v1.IntegrationConditionExposureAvailable,
+		corev1.ConditionFalse,
+		"RouteNotAvailable",
+		"explicitly disabled",
+	)
 	traitsCatalog := environment.Catalog
-	err := traitsCatalog.apply(environment)
-
-	assert.Nil(t, err)
+	conditions, err := traitsCatalog.apply(environment)
+	require.NoError(t, err)
+	assert.Contains(t, conditions, expectedCondition)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.Nil(t, environment.GetTrait("route"))
 
@@ -255,9 +264,10 @@ func TestRoute_Configure_IntegrationKitOnly(t *testing.T) {
 	enabled := false
 	routeTrait.Enabled = &enabled
 
-	result, err := routeTrait.Configure(environment)
+	result, condition, err := routeTrait.Configure(environment)
 	assert.False(t, result)
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
 }
 
 func TestRoute_Host(t *testing.T) {
@@ -271,9 +281,10 @@ func TestRoute_Host(t *testing.T) {
 		},
 	}
 
-	err := traitsCatalog.apply(environment)
+	conditions, err := traitsCatalog.apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("route"))
 
@@ -301,9 +312,10 @@ func TestRoute_TLS_From_Secret_reencrypt(t *testing.T) {
 			TLSDestinationCACertificateSecret: tlsMultipleSecretsName + "/" + tlsMultipleSecretsCert3Key,
 		},
 	}
-	err := traitsCatalog.apply(environment)
+	conditions, err := traitsCatalog.apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("route"))
 
@@ -336,10 +348,10 @@ func TestRoute_TLS_wrong_secret(t *testing.T) {
 			TLSDestinationCACertificateSecret: "404",
 		},
 	}
-	err := traitsCatalog.apply(environment)
-
+	conditions, err := traitsCatalog.apply(environment)
+	assert.Empty(t, conditions)
 	// there must be errors as the trait has wrong configuration
-	assert.NotNil(t, err)
+	require.Error(t, err)
 	assert.Nil(t, environment.GetTrait("route"))
 
 	route := environment.Resources.GetRoute(func(r *routev1.Route) bool {
@@ -364,10 +376,10 @@ func TestRoute_TLS_secret_wrong_key(t *testing.T) {
 			TLSCACertificateSecret: tlsMultipleSecretsName + "/foo",
 		},
 	}
-	err := traitsCatalog.apply(environment)
-
+	conditions, err := traitsCatalog.apply(environment)
+	assert.Empty(t, conditions)
 	// there must be errors as the trait has wrong configuration
-	assert.NotNil(t, err)
+	require.Error(t, err)
 	assert.Nil(t, environment.GetTrait("route"))
 
 	route := environment.Resources.GetRoute(func(r *routev1.Route) bool {
@@ -392,10 +404,10 @@ func TestRoute_TLS_secret_missing_key(t *testing.T) {
 			TLSCACertificateSecret: tlsMultipleSecretsName,
 		},
 	}
-	err := traitsCatalog.apply(environment)
-
+	conditions, err := traitsCatalog.apply(environment)
+	assert.Empty(t, conditions)
 	// there must be errors as the trait has wrong configuration
-	assert.NotNil(t, err)
+	require.Error(t, err)
 	assert.Nil(t, environment.GetTrait("route"))
 
 	route := environment.Resources.GetRoute(func(r *routev1.Route) bool {
@@ -421,9 +433,9 @@ func TestRoute_TLS_reencrypt(t *testing.T) {
 			TLSDestinationCACertificate: destinationCaCert,
 		},
 	}
-	err := traitsCatalog.apply(environment)
-
-	assert.Nil(t, err)
+	conditions, err := traitsCatalog.apply(environment)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("route"))
 
@@ -455,9 +467,9 @@ func TestRoute_TLS_edge(t *testing.T) {
 			TLSCACertificate: caCert,
 		},
 	}
-	err := traitsCatalog.apply(environment)
-
-	assert.Nil(t, err)
+	conditions, err := traitsCatalog.apply(environment)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("route"))
 
@@ -487,9 +499,9 @@ func TestRoute_TLS_passthrough(t *testing.T) {
 			TLSInsecureEdgeTerminationPolicy: string(routev1.InsecureEdgeTerminationPolicyAllow),
 		},
 	}
-	err := traitsCatalog.apply(environment)
-
-	assert.Nil(t, err)
+	conditions, err := traitsCatalog.apply(environment)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("route"))
 
@@ -517,9 +529,9 @@ func TestRoute_WithCustomServicePort(t *testing.T) {
 	}
 
 	traitsCatalog := environment.Catalog
-	err := traitsCatalog.apply(environment)
-
-	assert.Nil(t, err)
+	conditions, err := traitsCatalog.apply(environment)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("container"))
 	assert.NotNil(t, environment.GetTrait("route"))
@@ -538,3 +550,28 @@ func TestRoute_WithCustomServicePort(t *testing.T) {
 		route.Spec.Port.TargetPort.StrVal,
 	)
 }
+
+func TestRouteAnnotation(t *testing.T) {
+	annotationsTest := map[string]string{"haproxy.router.openshift.io/balance": "true"}
+
+	name := xid.New().String()
+	environment := createTestRouteEnvironment(t, name)
+	environment.Integration.Spec.Traits = v1.Traits{
+		Route: &traitv1.RouteTrait{
+			Annotations: map[string]string{"haproxy.router.openshift.io/balance": "true"},
+		},
+	}
+
+	traitsCatalog := environment.Catalog
+	conditions, err := traitsCatalog.apply(environment)
+	require.NoError(t, err)
+	assert.NotEmpty(t, conditions)
+
+	route := environment.Resources.GetRoute(func(r *routev1.Route) bool {
+		return r.ObjectMeta.Name == name
+	})
+
+	assert.NotNil(t, route)
+	assert.True(t, reflect.DeepEqual(route.GetAnnotations(), annotationsTest))
+
+}
