@@ -22,6 +22,7 @@ import (
 	"fmt"
 	"path"
 	"path/filepath"
+	"regexp"
 	"sort"
 	"strings"
 
@@ -35,7 +36,6 @@ import (
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/platform"
-	"github.com/apache/camel-k/v2/pkg/util"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/log"
@@ -45,8 +45,15 @@ import (
 const (
 	True  = "true"
 	False = "false"
+
+	sourceLanguageAnnotation    = "camel.apache.org/source.language"
+	sourceLoaderAnnotation      = "camel.apache.org/source.loader"
+	sourceNameAnnotation        = "camel.apache.org/source.name"
+	sourceCompressionAnnotation = "camel.apache.org/source.compression"
 )
 
+var capabilityDynamicProperty = regexp.MustCompile(`(\$\{([^}]*)\})`)
+
 // Identifiable represent an identifiable type.
 type Identifiable interface {
 	ID() ID
@@ -61,7 +68,7 @@ type Trait interface {
 	client.Injectable
 
 	// Configure the trait
-	Configure(environment *Environment) (bool, error)
+	Configure(environment *Environment) (bool, *TraitCondition, error)
 
 	// Apply executes a customization of the Environment
 	Apply(environment *Environment) error
@@ -69,11 +76,6 @@ type Trait interface {
 	// InfluencesKit determines if the trait has any influence on Integration Kits
 	InfluencesKit() bool
 
-	// InfluencesBuild defines a low level of granularity for those traits which influences the build.
-	// The trait can specify if any particular trait configuration influences a build or not.
-	// Note: You must override this method if you override `InfluencesKit()`
-	InfluencesBuild(this, prev map[string]interface{}) bool
-
 	// IsPlatformTrait marks all fundamental traits that allow the platform to work
 	IsPlatformTrait() bool
 
@@ -81,16 +83,18 @@ type Trait interface {
 	RequiresIntegrationPlatform() bool
 
 	// IsAllowedInProfile tells if the trait supports the given profile
-	IsAllowedInProfile(v1.TraitProfile) bool
+	IsAllowedInProfile(traitProfile v1.TraitProfile) bool
 
 	// Order is the order in which the trait should be executed in the normal flow
 	Order() int
 }
 
+// Comparable is the interface exposing comparable funcs.
 type Comparable interface {
-	Matches(Trait) bool
+	Matches(trait Trait) bool
 }
 
+// ComparableTrait is the interface used to compare two traits between them.
 type ComparableTrait interface {
 	Trait
 	Comparable
@@ -117,6 +121,16 @@ func NewBaseTrait(id string, order int) BaseTrait {
 	}
 }
 
+func NewBasePlatformTrait(id string, order int) BasePlatformTrait {
+	return BasePlatformTrait{
+		BaseTrait{
+			TraitID:        ID(id),
+			ExecutionOrder: order,
+			L:              log.Log.WithName("traits").WithValues("trait", id),
+		},
+	}
+}
+
 // BaseTrait is the root trait with noop implementations for hooks.
 type BaseTrait struct {
 	TraitID        ID            `json:"-"`
@@ -140,12 +154,6 @@ func (trait *BaseTrait) InfluencesKit() bool {
 	return false
 }
 
-// InfluencesBuild defines a low level of granularity for those traits which influences the build.
-// The trait can specify if any particular trait configuration influences a build or not.
-func (trait *BaseTrait) InfluencesBuild(this, prev map[string]interface{}) bool {
-	return false
-}
-
 // IsPlatformTrait marks all fundamental traits that allow the platform to work.
 func (trait *BaseTrait) IsPlatformTrait() bool {
 	return false
@@ -167,10 +175,20 @@ func (trait *BaseTrait) Order() int {
 	return trait.ExecutionOrder
 }
 
+// BasePlatformTrait is the root for platform traits with noop implementations for hooks.
+type BasePlatformTrait struct {
+	BaseTrait
+}
+
+// IsPlatformTrait marks all fundamental traits that allow the platform to work.
+func (trait *BasePlatformTrait) IsPlatformTrait() bool {
+	return true
+}
+
 // ControllerStrategySelector is the interface for traits that can determine the kind of controller that will run the integration.
 type ControllerStrategySelector interface {
 	// SelectControllerStrategy tells if the trait with current configuration can select a specific controller to use
-	SelectControllerStrategy(*Environment) (*ControllerStrategy, error)
+	SelectControllerStrategy(env *Environment) (*ControllerStrategy, error)
 	// ControllerStrategySelectorOrder returns the order (priority) of the controller strategy selector
 	ControllerStrategySelectorOrder() int
 }
@@ -187,6 +205,8 @@ type Environment struct {
 	Client client.Client
 	// The active Platform
 	Platform *v1.IntegrationPlatform
+	// The active IntegrationProfile
+	IntegrationProfile *v1.IntegrationProfile
 	// The current Integration
 	Integration *v1.Integration
 	// The IntegrationKit associated to the Integration
@@ -204,7 +224,6 @@ type Environment struct {
 	EnvVars               []corev1.EnvVar
 	ApplicationProperties map[string]string
 	Interceptors          []string
-	ServiceBindingSecret  string
 }
 
 // ControllerStrategy is used to determine the kind of controller that needs to be created for the integration.
@@ -298,7 +317,7 @@ func (e *Environment) DetermineProfile() v1.TraitProfile {
 	}
 
 	if e.Platform != nil {
-		return platform.GetProfile(e.Platform)
+		return platform.GetTraitProfile(e.Platform)
 	}
 
 	return v1.DefaultTraitProfile
@@ -399,6 +418,7 @@ func (e *Environment) computeApplicationProperties() (*corev1.ConfigMap, error)
 				Labels: map[string]string{
 					v1.IntegrationLabel:                e.Integration.Name,
 					"camel.apache.org/properties.type": "application",
+					kubernetes.ConfigMapTypeLabel:      CamelPropertiesType,
 				},
 			},
 			Data: map[string]string{
@@ -415,8 +435,9 @@ func (e *Environment) addSourcesProperties() {
 		e.ApplicationProperties = make(map[string]string)
 	}
 	idx := 0
-	for _, s := range e.Integration.Sources() {
-		if e.isEmbedded(s) {
+	for _, s := range e.Integration.AllSources() {
+		// We don't process routes embedded (native) or Kamelets
+		if e.isEmbedded(s) || s.IsGeneratedFromKamelet() {
 			continue
 		}
 		srcName := strings.TrimPrefix(filepath.ToSlash(s.Name), "/")
@@ -461,14 +482,14 @@ func (e *Environment) addSourcesProperties() {
 }
 
 func (e *Environment) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]corev1.VolumeMount) {
-	//
-	// Volumes :: Sources
-	//
+	// Sources
 	idx := 0
-	for _, s := range e.Integration.Sources() {
-		if e.isEmbedded(s) {
+	for _, s := range e.Integration.AllSources() {
+		// We don't process routes embedded (native) or Kamelets
+		if e.isEmbedded(s) || s.IsGeneratedFromKamelet() {
 			continue
 		}
+		// Routes are copied under /etc/camel/sources and discovered by the runtime accordingly
 		cmName := fmt.Sprintf("%s-source-%03d", e.Integration.Name, idx)
 		if s.ContentRef != "" {
 			cmName = s.ContentRef
@@ -487,24 +508,39 @@ func (e *Environment) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]c
 		*mnts = append(*mnts, *mnt)
 		idx++
 	}
-
+	// Resources (likely application properties or kamelets)
 	if e.Resources != nil {
 		e.Resources.VisitConfigMap(func(configMap *corev1.ConfigMap) {
-			propertiesType := configMap.Labels["camel.apache.org/properties.type"]
-			resName := propertiesType + ".properties"
+			switch configMap.Labels[kubernetes.ConfigMapTypeLabel] {
+			case CamelPropertiesType:
+				// Camel properties
+				propertiesType := configMap.Labels["camel.apache.org/properties.type"]
+				resName := propertiesType + ".properties"
 
-			var mountPath string
-			switch propertiesType {
-			case "application":
-				mountPath = filepath.Join(camel.BasePath, resName)
-			case "user":
-				mountPath = filepath.Join(camel.ConfDPath, resName)
-			}
+				var mountPath string
+				switch propertiesType {
+				case "application":
+					mountPath = filepath.Join(camel.BasePath, resName)
+				case "user":
+					mountPath = filepath.Join(camel.ConfDPath, resName)
+				}
 
-			if propertiesType != "" {
-				refName := propertiesType + "-properties"
-				vol := getVolume(refName, "configmap", configMap.Name, "application.properties", resName)
-				mnt := getMount(refName, mountPath, resName, true)
+				if propertiesType != "" {
+					refName := propertiesType + "-properties"
+					vol := getVolume(refName, "configmap", configMap.Name, "application.properties", resName)
+					mnt := getMount(refName, mountPath, resName, true)
+
+					*vols = append(*vols, *vol)
+					*mnts = append(*mnts, *mnt)
+				} else {
+					log.WithValues("Function", "trait.configureVolumesAndMounts").Infof("Warning: could not determine camel properties type %s", propertiesType)
+				}
+			case KameletBundleType:
+				// Kamelets bundle configmap
+				kameletMountPoint := configMap.Annotations[kameletMountPointAnnotation]
+				refName := KameletBundleType
+				vol := getVolume(refName, "configmap", configMap.Name, "", "")
+				mnt := getMount(refName, kameletMountPoint, "", true)
 
 				*vols = append(*vols, *vol)
 				*mnts = append(*mnts, *mnt)
@@ -512,9 +548,8 @@ func (e *Environment) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]c
 		})
 	}
 
-	//
-	// Volumes :: Additional ConfigMaps
-	//
+	// Deprecated - should use mount trait
+	// User provided configmaps
 	for _, configmaps := range e.collectConfigurations("configmap") {
 		refName := kubernetes.SanitizeLabel(configmaps["value"])
 		mountPath := getMountPoint(configmaps["value"], configmaps["resourceMountPoint"], "configmap", configmaps["resourceType"])
@@ -525,9 +560,8 @@ func (e *Environment) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]c
 		*mnts = append(*mnts, *mnt)
 	}
 
-	//
-	// Volumes :: Additional Secrets
-	//
+	// Deprecated - should use mount trait
+	// User provided secrets
 	for _, secret := range e.collectConfigurations("secret") {
 		refName := kubernetes.SanitizeLabel(secret["value"])
 		mountPath := getMountPoint(secret["value"], secret["resourceMountPoint"], "secret", secret["resourceType"])
@@ -537,21 +571,8 @@ func (e *Environment) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]c
 		*vols = append(*vols, *vol)
 		*mnts = append(*mnts, *mnt)
 	}
-	// append Service Binding secrets
-	if len(e.ServiceBindingSecret) > 0 {
-		secret := e.ServiceBindingSecret
-		refName := kubernetes.SanitizeLabel(secret)
-		mountPath := filepath.Join(camel.ServiceBindingsMountPath, strings.ToLower(secret))
-		vol := getVolume(refName, "secret", secret, "", "")
-		mnt := getMount(refName, mountPath, "", true)
-
-		*vols = append(*vols, *vol)
-		*mnts = append(*mnts, *mnt)
-	}
-
-	//
-	// Volumes :: Additional user provided volumes
-	//
+	// Deprecated - should use mount trait
+	// User provided volumes
 	for _, volumeConfig := range e.collectConfigurationValues("volume") {
 		configParts := strings.Split(volumeConfig, ":")
 
@@ -710,15 +731,16 @@ func (e *Environment) getIntegrationContainerPort() *corev1.ContainerPort {
 	return nil
 }
 
-// nolint: unused
-func (e *Environment) getAllInterceptors() []string {
-	res := make([]string, 0)
-	util.StringSliceUniqueConcat(&res, e.Interceptors)
-
-	if e.Integration != nil {
-		for _, s := range e.Integration.Sources() {
-			util.StringSliceUniqueConcat(&res, s.Interceptors)
+// CapabilityPropertyKey returns the key or expand any variable provided in it. vars variable contain the
+// possible dynamic values to use.
+func CapabilityPropertyKey(camelPropertyKey string, vars map[string]string) string {
+	if capabilityDynamicProperty.MatchString(camelPropertyKey) && vars != nil {
+		match := capabilityDynamicProperty.FindStringSubmatch(camelPropertyKey)
+		if len(match) < 2 {
+			// Should not happen, but fallback to the key not expanded instead of panic if it comes to happen
+			return camelPropertyKey
 		}
+		return strings.ReplaceAll(camelPropertyKey, match[1], vars[match[2]])
 	}
-	return res
+	return camelPropertyKey
 }
