@@ -191,7 +191,7 @@ const yamlRestDSL = `
           simple: "${body.contains(\",\")}"
       - split:
           tokenize: ";"
-      - set-body:
+      - setBody:
           simple: "${body.toLowerCase()}"
       - to:
           uri: "log:out"
@@ -215,7 +215,7 @@ const yamlRestDSLWithRoute = `
             simple: "${body.contains(\",\")}"
         - split:
             tokenize: ";"
-        - set-body:
+        - setBody:
             simple: "${body.toLowerCase()}"
         - to:
             uri: "log:out"
@@ -244,7 +244,7 @@ const yamlFromDSL = `
     parameters:
       period: "5000"
     steps:
-      - set-body:
+      - setBody:
           constant: "Hello Yaml !!!"
       - transform:
           simple: "${body.toUpperCase()}"
@@ -259,7 +259,7 @@ const yamlFromDSLWithRoute = `
       parameters:
         period: "5000"
     steps:
-      - set-body:
+      - setBody:
           constant: "Hello Yaml !!!"
       - transform:
           simple: "${body.toUpperCase()}"
@@ -275,8 +275,8 @@ func TestYAMLRouteAndFromEquivalence(t *testing.T) {
 		sourceContent := content
 		t.Run(name, func(t *testing.T) {
 			assertExtractYAML(t, inspector, sourceContent, func(meta *Metadata) {
-				assert.Equal(t, meta.FromURIs, []string{"timer:tick?period=5000"})
-				assert.Equal(t, meta.ToURIs, []string{"log:info"})
+				assert.Equal(t, []string{"timer:tick?period=5000"}, meta.FromURIs)
+				assert.Equal(t, []string{"log:info"}, meta.ToURIs)
 				assert.True(t, meta.Dependencies.Has("camel:log"))
 				assert.True(t, meta.Dependencies.Has("camel:timer"))
 			})
@@ -555,7 +555,7 @@ const yamlFromDSLWithPropertyPlaceholder = `
       parameters:
         period: "5000"
     steps:
-      - set-body:
+      - setBody:
           constant: "Hello Yaml !!!"
       - transform:
           simple: "${body.toUpperCase()}"
@@ -570,7 +570,7 @@ const yamlFromDSLWithPropertyPlaceholderScheme = `
       parameters:
         period: "5000"
     steps:
-      - set-body:
+      - setBody:
           constant: "Hello Yaml !!!"
       - transform:
           simple: "${body.toUpperCase()}"
@@ -607,7 +607,7 @@ func TestYAMLRouteWithPropertyPlaceholder(t *testing.T) {
 				for _, k := range test.toURIs {
 					assert.Contains(t, meta.ToURIs, k)
 				}
-				assert.Equal(t, meta.Dependencies.Size(), 2)
+				assert.Equal(t, 2, meta.Dependencies.Size())
 				assert.True(t, meta.Dependencies.Has("camel:core"))
 				assert.True(t, meta.Dependencies.Has("camel:timer"))
 			})
